<?php
/*
 * Elementor Proffer Causes Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_Causes extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_causes';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Causes', 'proffer-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer Causes widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['tmx-proffer_causes'];
	}

	/**
	 * Register Proffer Causes widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){


		$posts = get_posts( 'post_type="causes"&numberposts=-1' );
    $PostID = array();
    if ( $posts ) {
      foreach ( $posts as $post ) {
        $PostID[ $post->ID ] = $post->ID;
      }
    } else {
      $PostID[ __( 'No ID\'s found', 'proffer' ) ] = 0;
    }


		$this->start_controls_section(
			'section_causes_listing',
			[
				'label' => esc_html__( 'Causes Options', 'proffer-core' ),
			]
		);
		$this->add_control(
			'causes_style',
			[
				'label' => esc_html__( 'Cause Style', 'proffer-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__( 'Style One', 'proffer-core' ),
					'style-two' => esc_html__( 'Style Two', 'proffer-core' ),
				],
				'default' => 'style-one',
				'description' => esc_html__( 'Select your Cause style.', 'proffer-core' ),
			]
		);
		$this->add_control(
			'sub_title',
			[
				'label' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Sub Type title text here', 'proffer-core' ),
				'label_block' => true,
				'condition' => [
					'causes_style' => array('style-two'),
				],
			]
		);
		$this->add_control(
			'section_title',
			[
				'label' => esc_html__( 'Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
				'condition' => [
					'causes_style' => array('style-two'),
				],
			]
		);
		$this->add_control(
			'case_image',
			[
				'label' => esc_html__( 'Causes Image', 'proffer-core' ),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__( 'Set your image.', 'proffer-core'),
				'condition' => [
					'causes_style' => array('style-two'),
				],
			]
		);
		$this->add_control(
			'causes_limit',
			[
				'label' => esc_html__( 'Causes Limit', 'proffer-core' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 100,
				'step' => 1,
				'default' => 3,
				'description' => esc_html__( 'Enter the number of items to show.', 'proffer-core' ),
			]
		);
		$this->add_control(
			'causes_order',
			[
				'label' => __( 'Order', 'proffer-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'ASC' => esc_html__( 'Asending', 'proffer-core' ),
					'DESC' => esc_html__( 'Desending', 'proffer-core' ),
				],
				'default' => 'DESC',
			]
		);
		$this->add_control(
			'causes_orderby',
			[
				'label' => __( 'Order By', 'proffer-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'None', 'proffer-core' ),
					'ID' => esc_html__( 'ID', 'proffer-core' ),
					'author' => esc_html__( 'Author', 'proffer-core' ),
					'title' => esc_html__( 'Title', 'proffer-core' ),
					'date' => esc_html__( 'Date', 'proffer-core' ),
				],
				'default' => 'date',
			]
		);
		$this->add_control(
			'causes_show_category',
			[
				'label' => __( 'Certain Categories?', 'proffer-core' ),
				'type' => Controls_Manager::SELECT2,
				'default' => [],
				'options' => Controls_Helper_Output::get_terms_names( 'causes_category'),
				'multiple' => true,
			]
		);
		$this->add_control(
			'causes_show_id',
			[
				'label' => __( 'Certain ID\'s?', 'proffer-core' ),
				'type' => Controls_Manager::SELECT2,
				'default' => [],
				'options' => $PostID,
				'multiple' => true,
			]
		);
		$this->add_control(
			'short_content',
			[
				'label' => esc_html__( 'Excerpt Length', 'proffer-core' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'step' => 1,
				'default' => 55,
				'description' => esc_html__( 'How many words you want in short content paragraph.', 'proffer-core' ),
			]
		);
		$this->add_control(
			'read_more_txt',
			[
				'label' => esc_html__( 'Read More Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Type your Read More text here', 'proffer-core' ),
			]
		);
		$this->add_control(
			'causes_more',
			[
				'label' => esc_html__( 'Read More', 'proffer-core' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'proffer-core' ),
				'label_off' => esc_html__( 'Hide', 'proffer-core' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
		$this->end_controls_section();// end: Section

		// Subtitle
		$this->start_controls_section(
			'section_subtitle_style',
			[
				'label' => esc_html__( 'Subtitle', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'causes_style' => array('style-two'),
				],
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .campain-section .section-title span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'subtitle_padding',
			[
				'label' => esc_html__( 'Subtitle Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .campain-section .section-title span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'causes_style' => array('style-two'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .campain-section .section-title h2 a',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .campain-section .section-title h2 a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .campain-section .section-title h2 a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Campain Title
		$this->start_controls_section(
			'section_campain_title_style',
			[
				'label' => esc_html__( 'Campain Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_campain_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .campain-section .campain-slider h3 a, .causes-section .inner h3 a',
			]
		);
		$this->add_control(
			'campain_content_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .campain-section .campain-slider h3 a, .causes-section .inner h3 a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .campain-section .campain-slider p',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .campain-section .campain-slider p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Number
		$this->start_controls_section(
			'section_content_number_style',
			[
				'label' => esc_html__( 'Number', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_content_number_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .causes-section .goal-raised span',
			]
		);
		$this->add_control(
			'content_number_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .causes-section .goal-raised span,.campain-section .campain-slider .goal-raised,.campain-section .campain-slider .goal-raised span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Overly
		$this->start_controls_section(
			'section_overly_style',
			[
				'label' => esc_html__( 'Overly', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'causes_style' => array('style-one'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => esc_html__( 'Overly Background', 'proffer-core' ),
				'description' => esc_html__( 'Causes Overly Color', 'proffer-core' ),
				'types' => [ 'gradient','classic' ],
				'selector' => '{{WRAPPER}} .causes-section .overlay:before',
			]
		);
		$this->end_controls_section();// end: Section


	}

	/**
	 * Render Causes widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$causes_style = !empty( $settings['causes_style'] ) ? $settings['causes_style'] : '';

		$causes_limit = !empty( $settings['causes_limit'] ) ? $settings['causes_limit'] : '';
		$causes_order = !empty( $settings['causes_order'] ) ? $settings['causes_order'] : '';
		$causes_orderby = !empty( $settings['causes_orderby'] ) ? $settings['causes_orderby'] : '';
		$causes_show_category = !empty( $settings['causes_show_category'] ) ? $settings['causes_show_category'] : [];
		$causes_show_id = !empty( $settings['causes_show_id'] ) ? $settings['causes_show_id'] : [];
		$short_content = !empty( $settings['short_content'] ) ? $settings['short_content'] : '';
		$read_more_txt = !empty( $settings['read_more_txt'] ) ? $settings['read_more_txt'] : '';

		$causes_more = !empty( $settings['causes_more'] ) ? $settings['causes_more'] : [];

		$sub_title = !empty( $settings['sub_title'] ) ? $settings['sub_title'] : [];
		$section_title = !empty( $settings['section_title'] ) ? $settings['section_title'] : [];
		$case_image = !empty( $settings['case_image']['id'] ) ? $settings['case_image']['id'] : [];

		// Image
		$case_url = wp_get_attachment_url( $case_image );

		$excerpt_length = $short_content ? $short_content : '25';
		$read_more_txt = $read_more_txt ? $read_more_txt : esc_html__( 'Read More', 'proffer-core' );


		// Turn output buffer on
		ob_start();

		// Pagination
		global $paged;
		if( get_query_var( 'paged' ) )
		  $my_page = get_query_var( 'paged' );
		else {
		  if( get_query_var( 'page' ) )
			$my_page = get_query_var( 'page' );
		  else
			$my_page = 1;
		  set_query_var( 'paged', $my_page );
		  $paged = $my_page;
		}

    if ($causes_show_id) {
			$causes_show_id = json_encode( $causes_show_id );
			$causes_show_id = str_replace(array( '[', ']' ), '', $causes_show_id);
			$causes_show_id = str_replace(array( '"', '"' ), '', $causes_show_id);
      $causes_show_id = explode(',',$causes_show_id);
    } else {
      $causes_show_id = '';
    }

		$args = array(
		  // other query params here,
		  'paged' => $my_page,
		  'post_type' => 'give_forms',
		  'posts_per_page' => (int)$causes_limit,
		  'category_name' => implode(',', $causes_show_category),
		  'orderby' => $causes_orderby,
		  'order' => $causes_order,
      'post__in' => $causes_show_id,
		);

		$proffer_causes = new \WP_Query( $args );

		if ( $causes_style == 'style-one') { ?>
		<div class="causes-section">
    	<div class="content-area causes-slider">
	 			<?php
					if ( $proffer_causes->have_posts()) : while ( $proffer_causes->have_posts()) : $proffer_causes->the_post();

					$causes_options = get_post_meta( get_the_ID(), 'causes_options', true );
          $causes_image = isset( $causes_options['causes_image']) ? $causes_options['causes_image'] : '';
          global $post;
          $image_url = wp_get_attachment_url( $causes_image );
          $image_alt = get_post_meta( $causes_image , '_wp_attachment_image_alt', true);

					$form        = new \Give_Donate_Form( get_the_ID() );
					$goal_option = get_post_meta( get_the_ID(), '_give_goal_option', true );
					$goal        = $form->goal;
					$goal_format = get_post_meta( get_the_ID(), '_give_goal_format', true );
					$income      = $form->get_earnings();
					$color       = get_post_meta( get_the_ID(), '_give_goal_color', true );
					//Sanity check - ensure form has goal set to output
					if ( empty( $form->ID ) || ( is_singular( 'give_forms' ) && ! give_is_setting_enabled( $goal_option ) ) || ! give_is_setting_enabled( $goal_option ) || $goal == 0 ) {
					  return false;
					}
					$progress = round( ( $income / $goal ) * 100, 2 );
					if ( $income >= $goal ) {
					  $progress = 100;
					}
					$customer_id = give_get_payment_donor_id( get_the_ID() );
					$income = give_human_format_large_amount( give_format_amount( $income ) );
					$goal = give_human_format_large_amount( give_format_amount( $goal ) );
					$payment_mode = give_get_chosen_gateway( get_the_ID() );
					$form_action = add_query_arg( apply_filters( 'give_form_action_args', array( 'payment-mode' => $payment_mode, ) ),  give_get_current_page_url() );
					
					// remaining date
					$dead_line = get_post_meta( get_the_ID(), '_donation_form_metabox', true );
					$donation_deadline = $dead_line['donation_deadline'];
					$deadline = str_replace('/', '-', $donation_deadline);
					$deadline = date('F d, Y', strtotime($deadline));

					$date = strtotime($deadline);
					$remaining = $date - time();

					$days_remaining = floor($remaining / 86400);
					$hours_remaining = floor(($remaining % 86400) / 3600);
					$display_label_field = get_post_meta( get_the_ID(), '_give_checkout_label', true );
					$display_label       = ( ! empty( $display_label_field ) ? $display_label_field : esc_html__( 'Donate Now', 'groppe' ) );
					?>
          <div class="item">
	            <div class="inner">
	                <div class="img-holder">
	                  <?php if( $image_url ) { echo '<img src="'.esc_url( $image_url ).'" alt="'.esc_attr( $image_alt ).'">'; } ?>
	                </div>
	                <div class="overlay">
	                    <div class="overlay-content">
	                        <div class="progress">
	                            <div class="progress-bar" data-percent="<?php echo $progress; ?>"></div>
	                        </div>
	                       	<h3><a href="<?php echo esc_url( get_permalink() ); ?>"><?php echo esc_html(get_the_title()); ?></a></h3>
	                        <div class="goal-raised">
	                            <span><?php echo apply_filters( 'give_goal_amount_raised_output', give_currency_filter( $income ) ); ?> raised of <?php echo apply_filters( 'give_goal_amount_target_output', give_currency_filter( $goal ) ); ?></span>
	                             <a href="<?php echo esc_url( get_the_permalink() ); ?>" class="donate-btn">
	                             	<i class="fi flaticon-heart-1"></i><?php echo esc_html( $display_label ); ?>
	                             </a>
	                        </div>
	                    </div>
	                </div>
	            </div>
	        </div>
	       <?php
				  endwhile;
				  endif;
				  wp_reset_postdata();
				 ?>
	    	</div>
			</div>
			<?php } else { ?>
				<div class="campain-section">
			    <div class="content-area">
			        <div class="left-col">
			            <div class="campain-area">
			                <div class="section-title">
			                    <?php
			                    	 	if( $sub_title ) { echo '<span>'.esc_html( $sub_title ).'</span>'; } 
				            					if( $section_title ) { echo '<h2>'.esc_html( $section_title ).'</h2>'; } 
			                    ?>
			                </div>
			                <div class="campain-slider">
			                   
			                 <?php
												if ( $proffer_causes->have_posts()) : while ( $proffer_causes->have_posts()) : $proffer_causes->the_post();

												$causes_options = get_post_meta( get_the_ID(), 'causes_options', true );
							          $causes_image = isset( $causes_options['causes_image']) ? $causes_options['causes_image'] : '';
							          global $post;
							          $image_url = wp_get_attachment_url( $causes_image );
							          $image_alt = get_post_meta( $causes_image , '_wp_attachment_image_alt', true);

												$form        = new \Give_Donate_Form( get_the_ID() );
												$goal_option = get_post_meta( get_the_ID(), '_give_goal_option', true );
												$goal        = $form->goal;
												$goal_format = get_post_meta( get_the_ID(), '_give_goal_format', true );
												$income      = $form->get_earnings();
												$color       = get_post_meta( get_the_ID(), '_give_goal_color', true );
												//Sanity check - ensure form has goal set to output
												if ( empty( $form->ID ) || ( is_singular( 'give_forms' ) && ! give_is_setting_enabled( $goal_option ) ) || ! give_is_setting_enabled( $goal_option ) || $goal == 0 ) {
												  return false;
												}
												$progress = round( ( $income / $goal ) * 100, 2 );
												if ( $income >= $goal ) {
												  $progress = 100;
												}
												$customer_id = give_get_payment_donor_id( get_the_ID() );
												$income = give_human_format_large_amount( give_format_amount( $income ) );
												$goal = give_human_format_large_amount( give_format_amount( $goal ) );
												$payment_mode = give_get_chosen_gateway( get_the_ID() );
												$form_action = add_query_arg( apply_filters( 'give_form_action_args', array( 'payment-mode' => $payment_mode, ) ),  give_get_current_page_url() );
												
												// remaining date
												$dead_line = get_post_meta( get_the_ID(), '_donation_form_metabox', true );
												$donation_deadline = $dead_line['donation_deadline'];
												$deadline = str_replace('/', '-', $donation_deadline);
												$deadline = date('F d, Y', strtotime($deadline));

												$date = strtotime($deadline);
												$remaining = $date - time();

												$days_remaining = floor($remaining / 86400);
												$hours_remaining = floor(($remaining % 86400) / 3600);
												$display_label_field = get_post_meta( get_the_ID(), '_give_checkout_label', true );
												$display_label       = ( ! empty( $display_label_field ) ? $display_label_field : esc_html__( 'Donate Now', 'proffer' ) );
												?>
			                    <div class="item">
			                        <div>
			                            <h3>
			                            <a href="<?php echo esc_url( get_permalink() ); ?>"><?php echo esc_html(get_the_title()); ?></a>
			                            </h3>
			                            <p><?php echo $raw_content = give_get_meta( get_the_ID(), '_give_form_content', true ); ?></p>
			                            <div class="goal-raised">
			                                <div><span>Goal:</span><?php echo apply_filters( 'give_goal_amount_raised_output', give_currency_filter( $income ) ); ?></div>
			                                <div><span>Raised:</span><?php echo apply_filters( 'give_goal_amount_target_output', give_currency_filter( $goal ) ); ?></div>
			                            </div>
			                            <div class="progress">
			                                <div class="progress-bar" data-percent="<?php echo $progress; ?>"></div>
			                            </div>
			                            <a href="<?php echo esc_url( get_the_permalink() ); ?>" class="dontate-now">
			                            	<?php echo esc_html( $display_label ); ?>
			                            </a>
			                        </div>
			                    </div>
											 <?php
											  endwhile;
											  endif;
											  wp_reset_postdata();
											 ?>
			                </div>
			            </div>
			        </div>
			        <div class="right-col">
			            <div class="data-bg-image" data-background="<?php echo esc_url( $case_url ); ?>"></div>
			        </div>
			    </div>
			</div>
			<?php } 
			// Return outbut buffer
			echo ob_get_clean();
		}
	/**
	 * Render Causes widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_Causes() );