<?php
/*
 * Elementor Proffer Client Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_Client extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_client';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Client', 'proffer-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-images';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer Client widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['tmx-proffer_client'];
	}
	
	/**
	 * Register Proffer Client widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_client',
			[
				'label' => esc_html__( 'Client Options', 'proffer-core' ),
			]
		);
		$this->add_control(
			'client_style',
			[
				'label' => __( 'Client Style', 'proffer-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__( 'Style One', 'proffer-core' ),
					'style-two' => esc_html__( 'Style Two', 'proffer-core' ),
				],
				'default' => 'style-one',
				'description' => esc_html__( 'Select your feature style.', 'proffer-core' ),
			]
		);
		$this->add_control(
			'sub_title',
			[
				'label' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Sub Type title text here', 'proffer-core' ),
				'label_block' => true,
				'condition' => [
					'client_style' => array('style-two'),
				],
			]
		);
		$this->add_control(
			'section_title',
			[
				'label' => esc_html__( 'Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
				'condition' => [
					'client_style' => array('style-two'),
				],
			]
		);
		$this->add_control(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'default' => esc_html__( 'your content text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type your content here', 'proffer-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'condition' => [
					'client_style' => array('style-two'),
				],
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'client_title',
			[
				'label' => esc_html__( 'Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'client_logo',
			[
				'label' => esc_html__( 'Logo Image', 'proffer-core' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				
			]
		);
		$repeater->add_control(
			'client_link',
			[
				'label' => esc_html__( 'Link', 'proffer-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'proffer-core' ),
				'label_block' => true,
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		$this->add_control(
			'clientLogos_groups',
			[
				'label' => esc_html__( 'Client Logos', 'proffer-core' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'client_title' => esc_html__( 'Client', 'proffer-core' ),
					],
					
				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ client_title }}}',
			]
		);
		$this->end_controls_section();// end: Section

		// Sub Title
		$this->start_controls_section(
			'section_subtitle_style',
			[
				'label' => esc_html__( 'Sub Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'client_style' => array('style-two'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'sub_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .partner-section-s2 .section-title span',
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .partner-section-s2 .section-title span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'subtitle_padding',
			[
				'label' => __( 'Sub Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .partner-section-s2 .section-title span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section
	
		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .partner-section-s2 .section-title h2',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .partner-section-s2 .section-title h2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .partner-section-s2 .section-title h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'section_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .partner-section-s2 .partner-details p',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .partner-section-s2 .partner-details p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section
		
		
	}

	/**
	 * Render Client widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$clientLogos_groups = !empty( $settings['clientLogos_groups'] ) ? $settings['clientLogos_groups'] : [];
		$client_style = !empty( $settings['client_style'] ) ? $settings['client_style'] : '';

		$sub_title = !empty( $settings['sub_title'] ) ? $settings['sub_title'] : '';
		$section_title = !empty( $settings['section_title'] ) ? $settings['section_title'] : '';
		$section_content = !empty( $settings['section_content'] ) ? $settings['section_content'] : '';
		
		// Turn output buffer on
		ob_start();
		 ?>

		 <?php if ( $client_style == 'style-one') { ?>
		 <div class="partner-section">
				<div class="container">
					<div class="row">
						 <div class="partners-slider">
		          <?php 	// Group Param Output
								if( is_array( $clientLogos_groups ) && !empty( $clientLogos_groups ) ){
									foreach ( $clientLogos_groups as $each_logo ) { 

									$image_url = wp_get_attachment_url( $each_logo['client_logo']['id'] );
									$image_alt = get_post_meta( $each_logo['client_logo']['id'], '_wp_attachment_image_alt', true);

									$image_link = !empty( $each_logo['client_link']['url'] ) ? $each_logo['client_link']['url'] : '';
									$image_link_external = !empty( $each_logo['client_link']['is_external'] ) ? 'target="_blank"' : '';
									$image_link_nofollow = !empty( $each_logo['client_link']['nofollow'] ) ? 'rel="nofollow"' : '';
									$image_link_attr = !empty( $image_link ) ?  $image_link_external.' '.$image_link_nofollow : '';

									?>
		              <div class="grid">
		                <?php if( $image_link ) { echo '<a href="'.esc_url( $image_link ).'" '.esc_attr( $image_link_attr ).'>'; } ?>
		                    <img src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( $image_alt ); ?>">
		                <?php if( $image_link ) { echo '</a>'; } ?>
		               </div>
		            <?php }
								} ?>
		          </div>
					</div>
				</div>
			</div>
		 <?php } else { ?>
		<div class="partner-section-s2">
		    <div class="row">
		        <div class="col col-md-5">
		            <div class="section-title">
		               <?php 
                    	if( $sub_title ) { echo '<span>'.esc_html( $sub_title ).'</span>'; } 
		                  if( $section_title ) { echo '<h2>'.esc_html( $section_title ).'</h2>'; } 
                    ?>
		            </div>
		            <div class="partner-details">
		               <?php if( $section_content ) { echo '<p>'.esc_html( $section_content ).'</p>'; }  ?>
		            </div>
		        </div>
		        <div class="col col-md-7">
		            <div class="partners-area clearfix">
		              <?php 	// Group Param Output
									if( is_array( $clientLogos_groups ) && !empty( $clientLogos_groups ) ){
										foreach ( $clientLogos_groups as $each_logo ) { 

										$image_url = wp_get_attachment_url( $each_logo['client_logo']['id'] );
										$image_alt = get_post_meta( $each_logo['client_logo']['id'], '_wp_attachment_image_alt', true);

										$image_link = !empty( $each_logo['client_link']['url'] ) ? $each_logo['client_link']['url'] : '';
										$image_link_external = !empty( $each_logo['client_link']['is_external'] ) ? 'target="_blank"' : '';
										$image_link_nofollow = !empty( $each_logo['client_link']['nofollow'] ) ? 'rel="nofollow"' : '';
										$image_link_attr = !empty( $image_link ) ?  $image_link_external.' '.$image_link_nofollow : '';

										?>
		                <div>
		                   <?php if( $image_link ) { echo '<a href="'.esc_url( $image_link ).'" '.esc_attr( $image_link_attr ).'>'; } ?>
		                    <img src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( $image_alt ); ?>">
		                	<?php if( $image_link ) { echo '</a>'; } ?>
		                </div>
									<?php }
									} ?>
		            </div>
		        </div>
		    </div>
		</div>
		<?php } 

			// Return outbut buffer
			echo ob_get_clean();	
		}
	/**
	 * Render Client widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_Client() );