<?php
/*
 * Elementor Proffer ContactInfo Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_ContactInfo extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_contactinfo';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'ContactInfo', 'proffer-core' );
	}

	/**
	 * Retrieve the widget item.
	*/
	public function get_item() {
		return 'fa fa-telegram';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer ContactInfo widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['tmx-proffer_contactinfo'];
	}
	
	/**
	 * Register Proffer ContactInfo widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_contactinfo',
			[
				'label' => esc_html__( 'ContactInfo Options', 'proffer-core' ),
			]
		);
		$repeater = new Repeater();
    $repeater->add_control(
			'contact_icon',
			[
				'label' => __( 'Icon', 'proffer-core' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fi flaticon-house',
					'library' => 'solid',
				],
			]
		);
		$repeater->add_control(
			'contact_title',
			[
				'label' => esc_html__( 'Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Head Office', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'contact_content',
			[
				'label' => esc_html__( 'Content Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__( '54, Dahs udin sorok, Melborn Austria', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
    
		$this->add_control(
			'contactinfoItems_groups',
			[
				'label' => esc_html__( 'Contact Info Items', 'proffer-core' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'contact_title' => esc_html__( 'Contact Info', 'proffer-core' ),
					],
					
				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ contact_title }}}',
			]
		);
		$this->end_controls_section();// end: Section

	
		
		// Info Section
		$this->start_controls_section(
			'section_section_style',
			[
				'label' => esc_html__( 'Section', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'contact_info_bg_color',
				'label' => esc_html__( 'Background Color', 'proffer-core' ),
				'description' => esc_html__( 'Background Color', 'proffer-core' ),
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .contact-section .contact-info-grids > div',
			]
		);
		$this->end_controls_section();// end: Section

	
		// Info Icon
		$this->start_controls_section(
			'info_section_icon_style',
			[
				'label' => esc_html__( 'Icon', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'info_proffer_icon_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .contact-section .contact-info-grids .fi:before',
			]
		);
		$this->add_control(
			'info_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .contact-section .contact-info-grids .fi:before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section
		
		// Contaact Info Title
		$this->start_controls_section(
			'info_section_title_style',
			[
				'label' => esc_html__( 'Info Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'info_proffer_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .contact-section .contact-info-grids h4',
			]
		);
		$this->add_control(
			'info_title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .contact-section .contact-info-grids h4' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'info_title_padding',
			[
				'label' => __( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .contact-section .contact-info-grids h4' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Content
		$this->start_controls_section(
			'info_section_content_style',
			[
				'label' => esc_html__( 'Info Content', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'info_proffer_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .contact-section .contact-info-grids p',
			]
		);
		$this->add_control(
			'info_content_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .contact-section .contact-info-grids p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'info_content_padding',
			[
				'label' => __( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .contact-section .contact-info-grids p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section


	}

	/**
	 * Render ContactInfo widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$contactinfoItems_groups = !empty( $settings['contactinfoItems_groups'] ) ? $settings['contactinfoItems_groups'] : [];
		
		// Turn output buffer on
		ob_start();
		?>
	  <div class="contact-section">
	    <div class="contact-info-grids">
	        <?php 	// Group Param Output
					if( is_array( $contactinfoItems_groups ) && !empty( $contactinfoItems_groups ) ){
					foreach ( $contactinfoItems_groups as $each_items ) { 

					$contact_title = !empty( $each_items['contact_title'] ) ? $each_items['contact_title'] : '';
					$contact_content = !empty( $each_items['contact_content'] ) ? $each_items['contact_content'] : '';

					$contact_icon = !empty( $each_items['contact_icon']['value'] ) ? $each_items['contact_icon']['value'] : '';
					$contact_svg_url = !empty( $each_items['contact_icon']['value']['url'] ) ? $each_items['contact_icon']['value']['url'] : '';
					$svg_alt = get_post_meta( $contact_svg_url , '_wp_attachment_image_alt', true);

					?>
	        <div class="grid">
	            
	           <?php  
	           	if ( $contact_svg_url ) { 
          			 echo '<img src="'.esc_url( $contact_svg_url ).'" alt="'.esc_url( $svg_alt ).'">';
          		} else {
          			echo '<i class="'.esc_attr( $contact_icon ).'"></i>';
          		}
	          	if( $contact_title ) { echo '<h4>'.esc_html( $contact_title ).'</h4>'; }
			       	if( $contact_content ) { echo '<p>'.wp_kses_post( $contact_content ).'</p>'; }
	           ?>
	        </div>
					<?php }
				} ?>
	    </div>
	</div>
		<?php
			// Return outbut buffer
			echo ob_get_clean();	
		}
	/**
	 * Render ContactInfo widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_ContactInfo() );