<?php
/*
 * Elementor Proffer CTA Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_CTA extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_cta';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'CTA', 'proffer-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-bullhorn';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer CTA widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	/*
	public function get_script_depends() {
		return ['tmx-proffer_cta'];
	}
	*/
	
	/**
	 * Register Proffer CTA widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_CTA',
			[
				'label' => esc_html__( 'CTA Options', 'proffer-core' ),
			]
		);
		$this->add_control(
			'cta_style',
			[
				'label' => __( 'CTA Style', 'proffer-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__( 'Style One', 'proffer-core' ),
					'style-two' => esc_html__( 'Style Two', 'proffer-core' ),
					'style-three' => esc_html__( 'Style Three', 'proffer-core' ),
				],
				'default' => 'style-one',
				'description' => esc_html__( 'Select your about style.', 'proffer-core' ),
			]
		);
		$this->add_control(
			'cta_image',
			[
				'label' => esc_html__( 'CTA Image', 'proffer-core' ),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__( 'Set your image.', 'proffer-core'),
				'condition' => [
					'cta_style' => array('style-one'),
				],
			]
		);
		$this->add_control(
			'sub_title',
			[
				'label' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type Sub title text here', 'proffer-core' ),
				'label_block' => true,
				'condition' => [
					'cta_style' => array('style-one'),
				],
			]
		);
		$this->add_control(
			'cta_title',
			[
				'label' => esc_html__( 'Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'cta_content',
			[
				'label' => esc_html__( 'Content Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__( 'Content Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type Content text here', 'proffer-core' ),
				'label_block' => true,
				'condition' => [
					'cta_style' => array('style-one'),
				],
			]
		);
		$this->add_control(
			'btn_text',
			[
				'label' => esc_html__( 'Button Text', 'proffer-core' ),
				'default' => esc_html__( 'button text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type button Text here', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'cta_style' => array('style-one','style-three'),
				],
			]
		);
		$this->add_control(
			'btn_link',
			[
				'label' => esc_html__( 'Button Link', 'proffer-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'https://your-link.com',
				'default' => [
					'url' => '',
				],
				'label_block' => true,
				'condition' => [
					'cta_style' => array('style-one','style-three'),
				],
			]
		);
		$this->add_control(
			'btn_text2',
			[
				'label' => esc_html__( 'Button 2 Text', 'proffer-core' ),
				'default' => esc_html__( 'button text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type button Text here', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'cta_style' => array('style-three'),
				],
			]
		);
		$this->add_control(
			'btn_link2',
			[
				'label' => esc_html__( 'Button 2 Link', 'proffer-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'https://your-link.com',
				'default' => [
					'url' => '',
				],
				'label_block' => true,
				'condition' => [
					'cta_style' => array('style-three'),
				],
			]
		);
		$this->add_control(
			'video_btn',
			[
				'label' => esc_html__( 'Video link', 'proffer-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__( 'Video link', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type Video link here', 'proffer-core' ),
				'label_block' => true,
				'condition' => [
					'cta_style' => array('style-two'),
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Sub Title
		$this->start_controls_section(
			'section_subtitle_style',
			[
				'label' => esc_html__( 'Sub Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'cta_style' => array('style-one'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'sub_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .cta-s1-section .section-title span',
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cta-s1-section .section-title span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'subtitle_padding',
			[
				'label' => __( 'Sub Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .cta-s1-section .section-title span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section
	
		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .cta-s1-section .section-title h2, .cta-s2-section h3, .cta-section-s3 h3',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cta-s1-section .section-title h2, .cta-s2-section h3, .cta-section-s3 h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .cta-s1-section .section-title h2 span' => '-webkit-text-stroke-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .cta-s1-section .section-title h2, .cta-s2-section h3, .cta-section-s3 h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'cta_style' => array('style-one'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'section_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .cta-s1-section .details p',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cta-s1-section .details p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Button
		$this->start_controls_section(
			'section_content_button_style',
			[
				'label' => esc_html__( 'Button', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'cta_style' => array('style-one','style-three'),
				],
			]
		);
		$this->add_control(
			'button_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cta-s1-section .theme-btn-s6, .cta-section-s3 .btns > a:first-child' => 'color: {{VALUE}};',
				],
			]
		);	
		$this->add_control(
			'button_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cta-s1-section .theme-btn-s6, .cta-section-s3 .btns > a:first-child' => 'background-color: {{VALUE}};',
				],
			]
		);	
		$this->end_controls_section();// end: Section

		// Button
		$this->start_controls_section(
			'section_content_button2_style',
			[
				'label' => esc_html__( 'Button 2', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'cta_style' => array('style-three'),
				],
			]
		);
		$this->add_control(
			'button2_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cta-section-s3 .btns > a.theme-btn-s9' => 'color: {{VALUE}};',
				],
			]
		);	
		$this->add_control(
			'button2_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cta-section-s3 .btns > a.theme-btn-s9' => 'background-color: {{VALUE}};',
				],
			]
		);	
		$this->end_controls_section();// end: Section


	}

	/**
	 * Render CTA widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$cta_style = !empty( $settings['cta_style'] ) ? $settings['cta_style'] : '';

		$cta_title = !empty( $settings['cta_title'] ) ? $settings['cta_title'] : '';
		$sub_title = !empty( $settings['sub_title'] ) ? $settings['sub_title'] : '';
		$cta_content = !empty( $settings['cta_content'] ) ? $settings['cta_content'] : '';
		$video_btn = !empty( $settings['video_btn'] ) ? $settings['video_btn'] : '';

		$button_text = !empty( $settings['btn_text'] ) ? $settings['btn_text'] : '';	
		$button_link = !empty( $settings['btn_link']['url'] ) ? $settings['btn_link']['url'] : '';

		$button_text2 = !empty( $settings['btn_text2'] ) ? $settings['btn_text2'] : '';	
		$button_link2 = !empty( $settings['btn_link2']['url'] ) ? $settings['btn_link2']['url'] : '';

		$cta_image = !empty( $settings['cta_image']['id'] ) ? $settings['cta_image']['id'] : '';	

		$cta_url = wp_get_attachment_url( $cta_image );
		$cta_alt = get_post_meta( $cta_image, '_wp_attachment_image_alt', true);

		$proffer_button = $button_link ? '<a href="'.esc_url($button_link).'" class="theme-btn-s3">'.esc_html( $button_text ).'</a>' : '';


		if ( $cta_style == 'style-one' ) {
			$proffer_button = $button_link ? '<a href="'.esc_url($button_link).'" class="theme-btn-s6"><i class="fi flaticon-like"></i>'.esc_html( $button_text ).'</a>' : '';
		} else {
			$proffer_button = $button_link ? '<a href="'.esc_url($button_link).'" class="theme-btn-s8">'.esc_html( $button_text ).'</a>' : '';
		}

		$proffer_button2 = $button_link2 ? '<a href="'.esc_url($button_link2).'" class="theme-btn-s9">'.esc_html( $button_text2 ).'</a>' : '';
		$video_btn = $video_btn ? '<a href="'.esc_url( $video_btn ).'" class="video-btn" data-type="iframe"><i class="fi flaticon-play"></i></a>' : '';


		if ( $cta_style == 'style-one') {
			$cta_class = 'cta-section';
		} elseif ( $cta_style == 'style-two' ) {
			$cta_class = 'cta-section-s2';
		} else {
			$cta_class = 'cta-section-s3';
		}

		// Turn output buffer on
		ob_start(); ?>

		<?php if ( $cta_style == 'style-one' ) { ?>
		<div class="cta-s1-section">
		    <div class="row">
		        <div class="col col-lg-5 col-md-5">
		            <div class="img-holder">
		                 <?php if( $cta_url ) { echo '<img src="'.esc_url( $cta_url ).'" alt="'.esc_url( $cta_alt ).'">'; } ?>
		            </div>
		        </div>
		        <div class="col col-lg-6 col-lg-offset-1 col-md-7">
		            <div class="info-col">
		                <div class="section-title">
		                	<?php 
		                     if( $sub_title ) { echo '<span>'.esc_html( $sub_title ).'</span>'; }
		                     if( $cta_title ) { echo '<h2>'.wp_kses_post( $cta_title ).'</h2>'; }
		                   ?>
		                </div>
		                <div class="details">
		                    <?php 
		                     if( $cta_content ) { echo '<p>'.esc_html( $cta_content ).'</p>'; }
		                     echo $proffer_button;
		                   ?>
		                </div>
		            </div>
		        </div>
		    </div>
		</div>
		<?php } elseif(  $cta_style == 'style-two' ) { ?>
		<div class="cta-s2-section">
		    <div class="row">
		        <div class="col col-xs-12">
		            <div class="col col-lg-8">
		                <div class="details">
		                    <?php  if( $cta_title ) { echo '<h3>'.esc_html( $cta_title ).'</h3>'; } ?>
		                </div>
		            </div>
		            <div class="col col-lg-4">
		                <div class="video-holder">
		                	<?php echo $video_btn; ?>
		                </div>
		            </div>
		        </div>
		    </div>
		</div>
		<?php } else { ?>
		<div class="cta-section-s3">
		    <div class="row">
		        <div class="col col-xs-12">
		            <div class="content-area">
		                <?php  if( $cta_title ) { echo '<h3>'.esc_html( $cta_title ).'</h3>'; } ?>
		                <div class="btns">
		                   <?php echo $proffer_button.$proffer_button2; ?>
		                </div>
		            </div>
		        </div>
		    </div>
		</div>
		<?php } 
		// Return outbut buffer
		echo ob_get_clean();
		
	}
	/**
	 * Render CTA widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_CTA() );