<?php
/*
 * Elementor Proffer Event Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_Event extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_event';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Event', 'proffer-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer Event widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['tmx-proffer_event'];
	}
	
	/**
	 * Register Proffer Event widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){


		$posts = get_posts( 'post_type="event"&numberposts=-1' );
    $PostID = array();
    if ( $posts ) {
      foreach ( $posts as $post ) {
        $PostID[ $post->ID ] = $post->ID;
      }
    } else {
      $PostID[ __( 'No ID\'s found', 'proffer' ) ] = 0;
    }
		

		$this->start_controls_section(
			'section_event_listing',
			[
				'label' => esc_html__( 'Listing Options', 'proffer-core' ),
			]
		);
		$this->add_control(
			'event_limit',
			[
				'label' => esc_html__( 'Event Limit', 'proffer-core' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 100,
				'step' => 1,
				'default' => 3,
				'description' => esc_html__( 'Enter the number of items to show.', 'proffer-core' ),
			]
		);
		$this->add_control(
			'event_order',
			[
				'label' => __( 'Order', 'proffer-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'ASC' => esc_html__( 'Asending', 'proffer-core' ),
					'DESC' => esc_html__( 'Desending', 'proffer-core' ),
				],
				'default' => 'DESC',
			]
		);
		$this->add_control(
			'event_orderby',
			[
				'label' => __( 'Order By', 'proffer-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'None', 'proffer-core' ),
					'ID' => esc_html__( 'ID', 'proffer-core' ),
					'author' => esc_html__( 'Author', 'proffer-core' ),
					'title' => esc_html__( 'Title', 'proffer-core' ),
					'date' => esc_html__( 'Date', 'proffer-core' ),
				],
				'default' => 'date',
			]
		);
		$this->add_control(
			'event_show_category',
			[
				'label' => __( 'Certain Categories?', 'proffer-core' ),
				'type' => Controls_Manager::SELECT2,
				'default' => [],
				'options' => Controls_Helper_Output::get_terms_names( 'event_category'),
				'multiple' => true,
			]
		);
		$this->add_control(
			'event_show_id',
			[
				'label' => __( 'Certain ID\'s?', 'proffer-core' ),
				'type' => Controls_Manager::SELECT2,
				'default' => [],
				'options' => $PostID,
				'multiple' => true,
			]
		);
		$this->end_controls_section();// end: Section

		// Section Title
		$this->start_controls_section(
			'section_event_section_listing',
			[
				'label' => esc_html__( 'Section Title', 'proffer-core' ),
			]
		);
		$this->add_control(
			'sub_title',
			[
				'label' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Sub Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'section_title',
			[
				'label' => esc_html__( 'Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'default' => esc_html__( 'your content text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type your content here', 'proffer-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);

		$this->end_controls_section();// end: Section



		// Subtitle
		$this->start_controls_section(
			'section_subtitle_style',
			[
				'label' => esc_html__( 'Subtitle', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .events-section .section-title span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'subtitle_padding',
			[
				'label' => esc_html__( 'Subtitle Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .events-section .section-title span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .events-section .section-title h2',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .events-section .section-title h2' => 'color: {{VALUE}};',
					'{{WRAPPER}} .events-section .section-title h2 span' => '-webkit-text-stroke-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .events-section .section-title h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section
		
		// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .events-section .about-details p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Event Title
		$this->start_controls_section(
			'section_event_title_style',
			[
				'label' => esc_html__( 'Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_event_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .events-section .inner h3 a',
			]
		);
		$this->add_control(
			'event_title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .events-section .inner h3 a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'event_title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .events-section .inner h3 a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Event Desc
		$this->start_controls_section(
			'section_event_desc_style',
			[
				'label' => esc_html__( 'Date', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_event_desc_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .events-section .inner p',
			]
		);
		$this->add_control(
			'event_desc_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .events-section .inner p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'event_desc_padding',
			[
				'label' => esc_html__( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .events-section .inner p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Overly
		$this->start_controls_section(
			'section_event_overly_style',
			[
				'label' => esc_html__( 'Overly', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'event_overly_background',
				'label' => esc_html__( 'Overly Background', 'proffer-core' ),
				'description' => esc_html__( 'Event Overly Color', 'proffer-core' ),
				'types' => [ 'gradient','classic' ],
				'selector' => '{{WRAPPER}} .events-section .grid:hover:before',
			]
		);
		$this->end_controls_section();// end: Section

		
	}

	/**
	 * Render Event widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();

		$sub_title = !empty( $settings['sub_title'] ) ? $settings['sub_title'] : '';
		$section_title = !empty( $settings['section_title'] ) ? $settings['section_title'] : '';
		$section_content = !empty( $settings['section_content'] ) ? $settings['section_content'] : '';

		$event_limit = !empty( $settings['event_limit'] ) ? $settings['event_limit'] : '';
		$event_order = !empty( $settings['event_order'] ) ? $settings['event_order'] : '';
		$event_orderby = !empty( $settings['event_orderby'] ) ? $settings['event_orderby'] : '';
		$event_show_category = !empty( $settings['event_show_category'] ) ? $settings['event_show_category'] : [];
		$event_show_id = !empty( $settings['event_show_id'] ) ? $settings['event_show_id'] : [];


		// Turn output buffer on
		ob_start();

		// Pagination
		global $paged;
		if( get_query_var( 'paged' ) )
		  $my_page = get_query_var( 'paged' );
		else {
		  if( get_query_var( 'page' ) )
			$my_page = get_query_var( 'page' );
		  else
			$my_page = 1;
		  set_query_var( 'paged', $my_page );
		  $paged = $my_page;
		}

    if ($event_show_id) {
			$event_show_id = json_encode( $event_show_id );
			$event_show_id = str_replace(array( '[', ']' ), '', $event_show_id);
			$event_show_id = str_replace(array( '"', '"' ), '', $event_show_id);
      $event_show_id = explode(',',$event_show_id);
    } else {
      $event_show_id = '';
    }

		$args = array(
		  // other query params here,
		  'paged' => $my_page,
		  'post_type' => 'event',
		  'posts_per_page' => (int)$event_limit,
		  'category_name' => implode(',', $event_show_category),
		  'orderby' => $event_orderby,
		  'order' => $event_order,
      'post__in' => $event_show_id,
		);

		$proffer_event = new \WP_Query( $args );

		?>
		<div class="events-section">
		    <div class="row">
		        <div class="col col-md-5">
		            <div class="section-title">
		                <?php 
                    	if( $sub_title ) { echo '<span>'.esc_html( $sub_title ).'</span>'; } 
		                  if( $section_title ) { echo '<h2>'.wp_kses_post( $section_title ).'</h2>'; } 
                    ?>
		            </div>
		            <div class="about-details">
	                <?php 
	                  if( $section_content ) { echo '<p>'.wp_kses_post( $section_content ).'</p>'; } 
                  ?>
		            </div>
		        </div>
		        <div class="col col-md-7">
		            <div class="events-slider-holder">
		                <div class="events-slider">
		                	<?php 
												if ( $proffer_event->have_posts()) : while ( $proffer_event->have_posts()) : $proffer_event->the_post();
												
												$event_options = get_post_meta( get_the_ID(), 'event_options', true );
							          $event_title = isset( $event_options['event_title']) ? $event_options['event_title'] : '';
							          $event_date = isset( $event_options['event_date']) ? $event_options['event_date'] : '';
							          $event_image = isset( $event_options['event_image']) ? $event_options['event_image'] : '';

							          global $post;
							          $image_url = wp_get_attachment_url( $event_image );
							          $image_alt = get_post_meta( $event_image , '_wp_attachment_image_alt', true);

												?>
		                    <div class="events-slider-item">
		                        <div class="grid">
		                            <div class="img-holder">
		                               <?php if( $image_url ) { echo '<img src="'.esc_url( $image_url ).'" alt="'.esc_attr( $image_alt ).'">'; } ?>
		                            </div>
		                            <div class="details">
		                                <div class="inner">
		                                 <?php  if( $event_title ) { echo '<h3><a href="'.esc_url( get_permalink() ).'">'.esc_html( $event_title ).'</a></h3>'; }
											            	 	if ( $event_date ) { ?>
									                   		<p><?php echo esc_html( $event_date ); ?></p>
											            	  <?php } ?>
		                                </div>
		                            </div>
		                        </div>
		                    </div>
		                 	<?php 
										  endwhile;
										  endif;
										  wp_reset_postdata();
										 ?>
		                </div>
		                <div class="events-slider-nav">
		                    <div class="events-slider-arrows">
		                        <div class="slider-prev"><i class="fi flaticon-back"></i></div>
		                        <div class="slider-next"><i class="fi flaticon-next"></i></div>
		                    </div>
		                </div>
		            </div>
		        </div>
		    </div>
		</div>
		<?php
			// Return outbut buffer
			echo ob_get_clean();	
		}
	/**
	 * Render Event widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_Event() );