<?php
/*
 * Elementor Proffer FeatureAbout Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_FeatureAbout extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_featureabout';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Feature About', 'proffer-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-file-signature';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer FeatureAbout widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['tmx-proffer_featureabout'];
	}
	
	/**
	 * Register Proffer FeatureAbout widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_featureabout',
			[
				'label' => esc_html__( 'Feature About Options', 'proffer-core' ),
			]
		);
		$this->add_control(
			'sub_title',
			[
				'label' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Sub Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'about_title',
			[
				'label' => esc_html__( 'Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'about_content',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'default' => esc_html__( 'your content text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type your content here', 'proffer-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$this->add_control(
			'btn_text',
			[
				'label' => esc_html__( 'Button Text', 'proffer-core' ),
				'default' => esc_html__( 'button text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type button Text here', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		$this->add_control(
			'btn_link',
			[
				'label' => esc_html__( 'Button Link', 'proffer-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'https://your-link.com',
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);
		$this->add_control(
			'btn_text2',
			[
				'label' => esc_html__( 'Button Text 2', 'proffer-core' ),
				'default' => esc_html__( 'button text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type button Text here', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		$this->add_control(
			'btn_link2',
			[
				'label' => esc_html__( 'Button Link 2', 'proffer-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'https://your-link.com',
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);
		$this->add_control(
			'about_image',
			[
				'label' => esc_html__( 'About Image', 'proffer-core' ),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__( 'Set your image.', 'proffer-core'),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'featureabout_icon',
			[
				'label' => __( 'Icon', 'proffer-core' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fi flaticon-pencil-case',
					'library' => 'solid',
				],
			]
		);
		$repeater->add_control(
			'featureabout_title',
			[
				'label' => esc_html__( 'Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'featureabout_content',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'default' => esc_html__( 'your content text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type your content here', 'proffer-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$this->add_control(
			'featureaboutItems_groups',
			[
				'label' => esc_html__( 'FeatureAbout', 'proffer-core' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'featureabout_title' => esc_html__( 'FeatureAbout', 'proffer-core' ),
					],
					
				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ featureabout_title }}}',
			]
		);
		$this->end_controls_section();// end: Section

		
		// Sub Title
		$this->start_controls_section(
			'section_subtitle_style',
			[
				'label' => esc_html__( 'Sub Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'sub_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .about-section .section-title span',
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .about-section .section-title span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'subtitle_padding',
			[
				'label' => __( 'Sub Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .about-section .section-title span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section
	
		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .about-section .section-title h2',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .about-section .section-title h2' => 'color: {{VALUE}};',
					'{{WRAPPER}} .about-section .section-title h2 span' => '-webkit-text-stroke-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .about-section .section-title h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'section_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .about-section .about-details p',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .about-section .about-details p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section
		
		// Icon
		$this->start_controls_section(
			'about_feature_section_icon_style',
			[
				'label' => esc_html__( 'Icon', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_about_feature_icon_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .about-section .about-features .icon i:before',
			]
		);
		$this->add_control(
			'about_feature_icon_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .about-section .about-features .icon i:before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Title
		$this->start_controls_section(
			'section_about_feature_title_style',
			[
				'label' => esc_html__( 'Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_about_feature_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .about-section .about-features h3',
			]
		);
		$this->add_control(
			'about_feature_title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .about-section .about-features h3' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'about_feature_title_padding',
			[
				'label' => __( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .about-section .about-features h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

	// Content
		$this->start_controls_section(
			'about_feature_section_content_style',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'about_feature_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .about-section .about-features p',
			]
		);
		$this->add_control(
			'about_feature_content_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .about-section .about-features p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		
	}

	/**
	 * Render FeatureAbout widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$featureaboutItems_groups = !empty( $settings['featureaboutItems_groups'] ) ? $settings['featureaboutItems_groups'] : [];

		$sub_title = !empty( $settings['sub_title'] ) ? $settings['sub_title'] : '';
		$about_title = !empty( $settings['about_title'] ) ? $settings['about_title'] : '';
		$about_content = !empty( $settings['about_content'] ) ? $settings['about_content'] : '';

		$about_info_title = !empty( $settings['about_info_title'] ) ? $settings['about_info_title'] : '';
		$about_info_name = !empty( $settings['about_info_name'] ) ? $settings['about_info_name'] : '';
		$bg_image = !empty( $settings['about_image']['id'] ) ? $settings['about_image']['id'] : '';	

		$button_text2 = !empty( $settings['btn_text2'] ) ? $settings['btn_text2'] : '';	
		$button_link2 = !empty( $settings['btn_link2']['url'] ) ? $settings['btn_link2']['url'] : '';
		$button_link_external2 = !empty( $settings['btn_link2']['is_external'] ) ? 'target="_blank"' : '';
		$button_link_nofollow2 = !empty( $settings['btn_link2']['nofollow'] ) ? 'rel="nofollow"' : '';
		$button_link_attr2 = !empty( $button_link2 ) ?  $button_link_external2.' '.$button_link_nofollow2 : '';

		$button_text = !empty( $settings['btn_text'] ) ? $settings['btn_text'] : '';	
		$button_link = !empty( $settings['btn_link']['url'] ) ? $settings['btn_link']['url'] : '';
		$button_link_external = !empty( $settings['btn_link']['is_external'] ) ? 'target="_blank"' : '';
		$button_link_nofollow = !empty( $settings['btn_link']['nofollow'] ) ? 'rel="nofollow"' : '';
		$button_link_attr = !empty( $button_link ) ?  $button_link_external.' '.$button_link_nofollow : '';
  
		// Image
		$image_url = wp_get_attachment_url( $bg_image );
		$image_alt = get_post_meta( $settings['about_image']['id'], '_wp_attachment_image_alt', true);

		$proffer_button = $button_link ? '<a href="'.esc_url($button_link).'" '.$button_link_attr.' class="theme-btn-s4">'.esc_html( $button_text ).'</a>' : '';

		$proffer_button2 = $button_link2 ? '<a href="'.esc_url($button_link2).'" '.$button_link_attr2.' class="theme-btn-s5">'.esc_html( $button_text2 ).'</a>' : '';

		
		// Turn output buffer on
		ob_start(); ?>
		<div class="about-section">
		    <div class="content-area">
		        <div class="left-col">
		            <div class="about-area">
		                <div class="section-title">
		                    <?php 
	                    	if( $sub_title ) { echo '<span>'.esc_html( $sub_title ).'</span>'; } 
			                  if( $about_title ) { echo '<h2>'.wp_kses_post( $about_title ).'</h2>'; } 
	                    ?>
		                </div>
		                <div class="about-details">
		                   <?php if( $about_content ) { echo '<P>'.esc_html( $about_content ).'</P>'; } ?>
		                    <div class="btns">
		                        <?php 
		                        	echo $proffer_button;
		                        	echo $proffer_button2;
		                         ?>
		                    </div>
		                    <div class="about-features">
		                        <?php 
						               // Group Param Output
														if( is_array( $featureaboutItems_groups ) && !empty( $featureaboutItems_groups ) ){
														foreach ( $featureaboutItems_groups as $each_item ) { 

														$featureabout_title = !empty( $each_item['featureabout_title'] ) ? $each_item['featureabout_title'] : '';
														$featureabout_content = !empty( $each_item['featureabout_content'] ) ? $each_item['featureabout_content'] : '';
														$featureabout_icon = !empty( $each_item['featureabout_icon']['value'] ) ? $each_item['featureabout_icon']['value'] : '';

														$featureabout_icon = !empty( $each_item['featureabout_icon']['value'] ) ? $each_item['featureabout_icon']['value'] : '';
														$featureabout_svg_url = !empty( $each_item['featureabout_icon']['value']['url'] ) ? $each_item['featureabout_icon']['value']['url'] : '';
														$svg_alt = get_post_meta( $featureabout_svg_url , '_wp_attachment_image_alt', true);

														?>
		                        <div>
		                            <div class="icon">
		                             <?php if ( $featureabout_svg_url ) { 
									            			 echo '<img src="'.esc_url( $featureabout_svg_url ).'" alt="'.esc_url( $svg_alt ).'">';
									            		} else {
									            			echo '<i class="'.esc_attr( $featureabout_icon ).'"></i>';
									            		} ?>
		                            </div>
		                           <?php 
		                            if( $featureabout_title ) { echo '<h3>'.esc_html( $featureabout_title ).'</h3>'; }
									            	if( $featureabout_content ) { echo ' <div><p>'.esc_html( $featureabout_content ).'<p></div>'; }
									             ?>
		                        </div>
													<?php }
													} ?>
		                    </div>
		                </div>
		            </div>
		        </div>
		        <div class="right-col data-bg-image" data-background="<?php echo esc_url( $image_url ); ?>">
		            <div class="img-holder">
		            </div>
		        </div>
		    </div> <!-- end content-area -->
		</div>
		<?php 
			// Return outbut buffer
			echo ob_get_clean();	
		}
	/**
	 * Render FeatureAbout widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_FeatureAbout() );