<?php
/*
 * Elementor Proffer Feature Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_Feature extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_feature';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Feature', 'proffer-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-file-signature';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer Feature widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['tmx-proffer_feature'];
	}
	
	/**
	 * Register Proffer Feature widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_feature',
			[
				'label' => esc_html__( 'Feature Options', 'proffer-core' ),
			]
		);
		$this->add_control(
			'feature_style',
			[
				'label' => __( 'Feature Style', 'proffer-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__( 'Style One', 'proffer-core' ),
					'style-two' => esc_html__( 'Style Two', 'proffer-core' ),
					'style-three' => esc_html__( 'Style Three', 'proffer-core' ),
				],
				'default' => 'style-one',
				'description' => esc_html__( 'Select your feature style.', 'proffer-core' ),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'feature_icon',
			[
				'label' => __( 'Icon', 'proffer-core' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fi flaticon-pencil-case',
					'library' => 'solid',
				],
			]
		);
		$repeater->add_control(
			'feature_title',
			[
				'label' => esc_html__( 'Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'feature_content',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'default' => esc_html__( 'your content text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type your content here', 'proffer-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$this->add_control(
			'featureItems_groups',
			[
				'label' => esc_html__( 'Feature', 'proffer-core' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'feature_title' => esc_html__( 'Feature', 'proffer-core' ),
					],
					
				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ feature_title }}}',
			]
		);
		$this->end_controls_section();// end: Section
		


		// Section
		$this->start_controls_section(
			'section_featue_style',
			[
				'label' => esc_html__( 'Section', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'feature_style' => array('style-one','style-two'),
				],
			]
		);
	  $this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'feature_section_bg_color',
				'label' => esc_html__( 'Background', 'proffer-core' ),
				'description' => esc_html__( 'Background Color', 'proffer-core' ),
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .feature-section .feature-grids .grid, .feature-section-s2 .feature-grids > .grid:nth-child(2)',
			]
		);
		$this->end_controls_section();// end: Section// Icon

		
		// Icon
		$this->start_controls_section(
			'section_icon_style',
			[
				'label' => esc_html__( 'Icon', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_icon_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .proffer-feature .feature-grids i:before',
			]
		);
		$this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .proffer-feature .feature-grids i:before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .proffer-feature .feature-grids h3',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .proffer-feature .feature-grids h3' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => __( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .proffer-feature .feature-grids h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

	// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'feature_style' => array('style-two','style-three'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'section_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .proffer-feature .feature-grids p',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .proffer-feature .feature-grids p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		
	}

	/**
	 * Render Feature widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$featureItems_groups = !empty( $settings['featureItems_groups'] ) ? $settings['featureItems_groups'] : [];
		$feature_style = !empty( $settings['feature_style'] ) ? $settings['feature_style'] : '';

		if ( $feature_style == 'style-one' ) {
			$feature_class = 'feature-section';
		} elseif ( $feature_style == 'style-two' ) {
			$feature_class = 'feature-section-s2';
		} else {
			$feature_class = 'about-page-section';
		}

		// Turn output buffer on
		ob_start();

		if ( $feature_style == 'style-one' || $feature_style == 'style-two' ) { ?>
			<div class="proffer-feature <?php echo esc_attr( $feature_class ); ?>">
		    <div class="row">
		        <div class="col col-xs-12">
		            <div class="feature-grids">
		               <?php 
		               // Group Param Output
										if( is_array( $featureItems_groups ) && !empty( $featureItems_groups ) ){
										foreach ( $featureItems_groups as $each_item ) { 

										$feature_title = !empty( $each_item['feature_title'] ) ? $each_item['feature_title'] : '';
										$feature_content = !empty( $each_item['feature_content'] ) ? $each_item['feature_content'] : '';
										$feature_icon = !empty( $each_item['feature_icon']['value'] ) ? $each_item['feature_icon']['value'] : '';

										$feature_icon = !empty( $each_item['feature_icon']['value'] ) ? $each_item['feature_icon']['value'] : '';
										$feature_svg_url = !empty( $each_item['feature_icon']['value']['url'] ) ? $each_item['feature_icon']['value']['url'] : '';
										$svg_alt = get_post_meta( $feature_svg_url , '_wp_attachment_image_alt', true);

										?>
		                <div class="grid">
		                    <?php if ( $feature_svg_url ) { 
					            			 echo '<img src="'.esc_url( $feature_svg_url ).'" alt="'.esc_url( $svg_alt ).'">';
					            		} else {
					            			echo '<i class="'.esc_attr( $feature_icon ).'"></i>';
					            		}
									        if( $feature_title ) { echo '<h3>'.esc_html( $feature_title ).'</h3>'; }
						            	if( $feature_content ) { echo ' <div><p>'.esc_html( $feature_content ).'<p></div>'; }
						             ?>
		                </div>
									<?php }
									} ?>
		            </div>
		        </div>
		    </div>
		</div>
		<?php } else { ?>
		<div class="proffer-feature about-page-section">
	    <div class="row">
	        <div class="col col-xs-12">
	            <div class="about-features-grid">
                 <?php 
	               // Group Param Output
									if( is_array( $featureItems_groups ) && !empty( $featureItems_groups ) ){
									foreach ( $featureItems_groups as $each_item ) { 

									$feature_title = !empty( $each_item['feature_title'] ) ? $each_item['feature_title'] : '';
									$feature_content = !empty( $each_item['feature_content'] ) ? $each_item['feature_content'] : '';
									$feature_icon = !empty( $each_item['feature_icon']['value'] ) ? $each_item['feature_icon']['value'] : '';

									$feature_icon = !empty( $each_item['feature_icon']['value'] ) ? $each_item['feature_icon']['value'] : '';
									$feature_svg_url = !empty( $each_item['feature_icon']['value']['url'] ) ? $each_item['feature_icon']['value']['url'] : '';
									$svg_alt = get_post_meta( $feature_svg_url , '_wp_attachment_image_alt', true);

									?>
	                <div class="grid">
	                    <?php if ( $feature_svg_url ) { 
				            			 echo '<img src="'.esc_url( $feature_svg_url ).'" alt="'.esc_url( $svg_alt ).'">';
				            		} else {
				            			echo ' <div class="icon"><i class="'.esc_attr( $feature_icon ).'"></i></div>';
				            		}
								        if( $feature_title ) { echo '<h3>'.esc_html( $feature_title ).'</h3>'; }
					            	if( $feature_content ) { echo '<p>'.esc_html( $feature_content ).'<p>'; }
					            ?>
	                </div>
	                <?php }
									} ?>
	            </div>
	        </div>
	    </div>                  
		</div>
		<?php } ?>




		<?php 
			// Return outbut buffer
			echo ob_get_clean();	
		}
	/**
	 * Render Feature widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_Feature() );