<?php
/*
 * Elementor Proffer Funfact Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_Funfact extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_funfact';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Funfact', 'proffer-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-sort-numeric-asc';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer Funfact widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['tmx-proffer_funfact'];
	}
	
	/**
	 * Register Proffer Funfact widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_funfact',
			[
				'label' => esc_html__( 'Funfact Options', 'proffer-core' ),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'funfact_title',
			[
				'label' => esc_html__( 'Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'funfact_number',
			[
				'label' => esc_html__( 'Funfact Number', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( '250', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type funfact Number here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'funfact_plus',
			[
				'label' => esc_html__( 'Funfact Plus/Percentage', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( '+', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type funfact Plus/Percentage here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'funfactItems_groups',
			[
				'label' => esc_html__( 'Funfact Items', 'proffer-core' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'funfact_title' => esc_html__( 'Funfact', 'proffer-core' ),
					],
					
				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ funfact_title }}}',
			]
		);
		$this->end_controls_section();// end: Section
		

		// Funfact Number
		$this->start_controls_section(
			'funfact_number_style',
			[
				'label' => esc_html__( 'Number', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_number_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .fun-fact-area .grid h3, .fun-fact-area .grid h3 span',
			]
		);
		$this->add_control(
			'number_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fun-fact-area .grid h3, .fun-fact-area .grid h3 span' => '-webkit-text-stroke-color: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'number_padding',
			[
				'label' => __( 'Number Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .fun-fact-area .grid h3, .fun-fact-area .grid h3 span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Funfact Title
		$this->start_controls_section(
			'funfact_title_style',
			[
				'label' => esc_html__( 'Funfact Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'ntrsvt_funfact_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .fun-fact-area .grid p',
			]
		);
		$this->add_control(
			'funfact_title',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fun-fact-area .grid p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'funfact_br_title',
			[
				'label' => esc_html__( 'Border Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fun-fact-area .grid p' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'funfact_title_padding',
			[
				'label' => __( 'Number Margin', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .fun-fact-area .grid p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		
	}

	/**
	 * Render Funfact widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$funfactItems_groups = !empty( $settings['funfactItems_groups'] ) ? $settings['funfactItems_groups'] : [];

		// Turn output buffer on
		ob_start();
		?>
		<div class="fun-fact-area">
		    <div class="fun-fact-grids clearfix">
					<?php 	// Group Param Output
						if( is_array( $funfactItems_groups ) && !empty( $funfactItems_groups ) ){
						foreach ( $funfactItems_groups as $each_item ) { 

						$funfact_title = !empty( $each_item['funfact_title'] ) ? $each_item['funfact_title'] : '';
						$funfact_number = !empty( $each_item['funfact_number'] ) ? $each_item['funfact_number'] : '';
						$funfact_plus = !empty( $each_item['funfact_plus'] ) ? $each_item['funfact_plus'] : '';

						?>
		        <div class="grid">
		            <div class="info">
		            	<?php 
		            		if( $funfact_number ) { echo ' <div><h3><span class="odometer" data-count="'.esc_html( $funfact_number ).'">'.esc_html__( '00','proffer-core' ).'</span>'.esc_html( $funfact_plus ).'</h3></div>'; } 
		            		if( $funfact_title ) { echo ' <div><p>'.wp_kses_post( $funfact_title ).'</p></div>'; } 
		            	?>
		            </div>
		        </div>
		      <?php }
					} ?>
		    </div>
		</div>
		<?php
			// Return outbut buffer
			echo ob_get_clean();	
		}
	/**
	 * Render Funfact widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_Funfact() );