<?php
/*
 * Elementor Proffer Instagram Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_Instagram extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_instagram';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Instagram', 'proffer-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-instagram';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer Instagram widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/

	public function get_script_depends() {
		return ['tmx-proffer_instagram'];
	}
	
	/**
	 * Register Proffer Instagram widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_Instagram',
			[
				'label' => esc_html__( 'Instagram Options', 'proffer-core' ),
			]
		);
		$this->add_control(
			'instagram_user_id',
			[
				'label' => esc_html__( 'Instagram User ID', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( '15054558209', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type Instagram User ID here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'instagram_access_token',
			[
				'label' => esc_html__( 'Instagram Access Token', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( '123456', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type Instagram Access Token here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'instagram_limit',
			[
				'label' => esc_html__( 'Instagram Limit', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( '10', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type Instagram Limit here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->end_controls_section();// end: Section


		// Content
		$this->start_controls_section(
			'section_instagram_style',
			[
				'label' => esc_html__( 'Instagram', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Icon', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .instagram-section .instagram-grids .grid a:after' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'overly_color',
			[
				'label' => esc_html__( 'Overly Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .instagram-section .instagram-grids .grid a:before' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		


	}

	/**
	 * Render Instagram widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();


		$instagram_user_id = !empty( $settings['instagram_user_id'] ) ? $settings['instagram_user_id'] : '';
		$instagram_access_token = !empty( $settings['instagram_access_token'] ) ? $settings['instagram_access_token'] : '';
		$instagram_limit = !empty( $settings['instagram_limit'] ) ? $settings['instagram_limit'] : '';

		
		// Turn output buffer on
		ob_start(); ?>

		<div class="instagram-section">
		    <div class="instagram-grids">
		        
		        <div class="instagram-feed" data-limit="<?php echo esc_attr( $instagram_limit ); ?>" data-token="<?php echo esc_attr( $instagram_access_token ); ?>" data-id="<?php echo esc_attr( $instagram_user_id ); ?>">
		        	 <div class="instaram-active" id="instafeed"></div>
			      </div>

		    </div>
		</div>

		<?php
		// Return outbut buffer
		echo ob_get_clean();
		
	}
	/**
	 * Render Instagram widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_Instagram() );