<?php
/*
 * Elementor Proffer Mission Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_Mission extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_mission';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Mission', 'proffer-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-network-wired';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer Mission widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['tmx-proffer_mission'];
	}
	
	/**
	 * Register Proffer Mission widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_mission',
			[
				'label' => esc_html__( 'Mission Options', 'proffer-core' ),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'mission_title',
			[
				'label' => esc_html__( 'Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'mission_content',
			[
				'label' => esc_html__( 'Content Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__( 'Content Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type content text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'mission_image',
			[
				'label' => esc_html__( 'Mission Image', 'proffer-core' ),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__( 'Set your image.', 'proffer-core'),
			]
		);
		$this->add_control(
			'missionItem_groups',
			[
				'label' => esc_html__( 'Mission Item', 'proffer-core' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'mission_title' => esc_html__( 'Mission', 'proffer-core' ),
					],
					
				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ mission_title }}}',
			]
		);
		$this->end_controls_section();// end: Section
		
		// Title
		$this->start_controls_section(
			'mission_section_style',
			[
				'label' => esc_html__( 'Section', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'section_active_color',
			[
				'label' => esc_html__( 'Overly Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .mission-vision-section .overlay:before' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'sasban_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .mission-vision-section .grid h3',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .mission-vision-section .grid h3' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => __( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .mission-vision-section .grid h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'section_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .mission-vision-section .grid p',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .mission-vision-section .grid p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'content_padding',
			[
				'label' => __( 'Content Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .mission-vision-section .grid p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section


		
	}

	/**
	 * Render Mission widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$missionItem_groups = !empty( $settings['missionItem_groups'] ) ? $settings['missionItem_groups'] : [];

		// Turn output buffer on
		ob_start();
		?>
		<div class="mission-vision-section">
        <div class="mission-vision-grids clearfix">
            <?php 	// Group Param Output
						if( is_array( $missionItem_groups ) && !empty( $missionItem_groups ) ){
						foreach ( $missionItem_groups as $each_item ) { 

						$mission_title = !empty( $each_item['mission_title'] ) ? $each_item['mission_title'] : '';
						$mission_content = !empty( $each_item['mission_content'] ) ? $each_item['mission_content'] : '';
						$image_url = wp_get_attachment_url($each_item['mission_image']['id'] );

						if ( $image_url ) {
							$mission_url = ' style="';
							$mission_url .= ( $image_url ) ? 'background-image: url( '. esc_url( $image_url ) .' );' : '';
							$mission_url .= '"';
						} else {
							$mission_url = '';
						}

						?>
            <div class="grid">
                <div class="overlay" <?php echo $mission_url; ?>></div>
               <?php 
		        	  if( $mission_title ) { echo '<h3>'.esc_html( $mission_title ).'</h3>'; } 
		        	  if( $mission_content ) { echo '<p>'.esc_html( $mission_content ).'</p>'; } 
		        	 ?>
            </div>
						<?php }
						} ?>
        </div>
		</div>
		<?php
			// Return outbut buffer
			echo ob_get_clean();	
		}
	/**
	 * Render Mission widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_Mission() );