<?php
/*
 * Elementor Proffer Skill Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_Skill extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_skill';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Skill', 'proffer-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-bar-chart';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer Skill widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['tmx-proffer_skill'];
	}
	
	/**
	 * Register Proffer Skill widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_skill',
			[
				'label' => esc_html__( 'Skill Options', 'proffer-core' ),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'skill_title',
			[
				'label' => esc_html__( 'Skill Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'skill_parcent',
			[
				'label' => esc_html__( 'Skill Percentage', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Skill Percentage', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type skill percentage here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'skillItems_groups',
			[
				'label' => esc_html__( 'Skill Items', 'proffer-core' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'skill_title' => esc_html__( 'Skill', 'proffer-core' ),
					],
					
				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ skill_title }}}',
			]
		);
		$this->end_controls_section();// end: Section
		

		// Skill Title
		$this->start_controls_section(
			'section_skil_style',
			[
				'label' => esc_html__( 'Skill Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'ntrsv_skill_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .our-skill-section .skills h6',
			]
		);
		$this->add_control(
			'skill_title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .our-skill-section .skills h6' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Skill Color
		$this->start_controls_section(
			'section_skil_color_style',
			[
				'label' => esc_html__( 'Skill Color', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'skill_bg_color',
			[
				'label' => esc_html__( 'Prograss BG Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .our-skill-section .skills .progress-bar,.our-skill-section .skills .progress-bar:after' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .our-skill-section .skills .progress > span' => 'color: {{VALUE}};'
				],
			]
		);
		$this->add_control(
			'skill_color',
			[
				'label' => esc_html__( 'Prograss Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .our-skill-section .skills .progress' => 'background-color: {{VALUE}};'
				],
			]
		);
		$this->end_controls_section();// end: Section

		
	}

	/**
	 * Render Skill widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$skillItems_groups = !empty( $settings['skillItems_groups'] ) ? $settings['skillItems_groups'] : [];

		$sub_title = !empty( $settings['sub_title'] ) ? $settings['sub_title'] : '';
		$skill_title = !empty( $settings['skill_title'] ) ? $settings['skill_title'] : '';
		$skill_content = !empty( $settings['skill_content'] ) ? $settings['skill_content'] : '';


		// Turn output buffer on
		ob_start();
		?>
		<div class="our-skill-section">
        <div class="details">
            <?php 
              if( $skill_content ) { echo '<p>'.esc_html( $skill_content ).'</p>'; } 
            ?>
            <div class="skills">
              <?php 	// Group Param Output
							if( is_array( $skillItems_groups ) && !empty( $skillItems_groups ) ){
								foreach ( $skillItems_groups as $each_items ) { 

								$skill_title = !empty( $each_items['skill_title'] ) ? $each_items['skill_title'] : '';
								$skill_parcent = !empty( $each_items['skill_parcent'] ) ? $each_items['skill_parcent'] : '';

								?>
                <div class="skill">
                	<?php if( $skill_title ) { echo '<h6>'.esc_html( $skill_title ).'</h6>'; }
                	if ( $skill_parcent ) { ?>
                	 <div class="progress">
                        <div class="progress-bar" data-percent="<?php echo esc_attr( $skill_parcent ) ?>"></div>
                    </div>
                	<?php } ?>
                </div>
               <?php }
								} ?>
            </div>
        </div>
		</div>
			<?php
			// Return outbut buffer
			echo ob_get_clean();	
		}
	/**
	 * Render Skill widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_Skill() );