<?php
/*
 * Elementor Proffer Blog Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_Slider extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_slider';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Slider', 'proffer-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-sliders';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer Slider widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	
	public function get_script_depends() {
		return ['tmx-proffer_slider'];
	}
	 
	
	/**
	 * Register Proffer Slider widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){

		$this->start_controls_section(
			'section_slider',
			[
				'label' => __( 'Slider Options', 'proffer-core' ),
			]
		);
		$this->add_control(
			'slide_style',
			[
				'label' => esc_html__( 'Slide Style', 'proffer-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__( 'Style One', 'proffer-core' ),
					'style-two' => esc_html__( 'Style Two', 'proffer-core' ),
					'style-three' => esc_html__( 'Style Three', 'proffer-core' ),
				],
				'default' => 'style-one',
				'description' => esc_html__( 'Select your Slide style.', 'proffer-core' ),
			]
		);
		$this->add_control(
			'hr',
			[
				'type' => Controls_Manager::DIVIDER,
			]
		);
		$this->add_control(
			'scroll_link',
			[
				'label' => esc_html__( 'Scroll Link Id', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( '#', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type pinterest link here', 'proffer-core' ),
				'label_block' => true,
				'condition' => [
					'slide_style' => array('style-one'),
				],
			]
		);
		$repeater = new Repeater();
		 $repeater->add_control(
			'slide_color',
			[
				'label' => esc_html__( 'Slide background Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#bbbbbb',
				'selectors' => [
					'{{WRAPPER}} .hero-slider' => 'background-color: {{VALUE}};',
				],
			]
		);
		$repeater->add_control(
			'slider_image',
			[
				'label' => esc_html__( 'Slider Image', 'proffer-core' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$repeater->add_control(
			'slider_title',
			[
				'label' => esc_html__( 'Slider title', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Type slide title here', 'proffer-core' ),
			]
		);
		$repeater->add_control(
			'slider_content',
			[
				'label' => esc_html__( 'Slider content', 'proffer-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'placeholder' => esc_html__( 'Type slide content here', 'proffer-core' ),
			]
		);
		$repeater->start_controls_tabs( 'button_optn' );
		$repeater->start_controls_tab(
			'button_one',
			[
				'label' => esc_html__( 'Button', 'proffer-core' ),
			]
		);
		$repeater->add_control(
			'btn_txt',
			[
				'label' => esc_html__( 'Button Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Type your button text here', 'proffer-core' ),
			]
		);
		$repeater->add_control(
			'button_link',
			[
				'label' => esc_html__( 'Button Link', 'proffer-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'proffer-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
				],
			]
		);
		$repeater->end_controls_tab();  // end:Button One tab
		$repeater->start_controls_tab(
			'button_two',
			[
				'label' => esc_html__( 'Video', 'proffer-core' ),
			]
		);
		$repeater->add_control(
			'button_two_link',
			[
				'label' => esc_html__( 'Video Link', 'proffer-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'proffer-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
				],
			]
		);
		$repeater->end_controls_tab();  // end:Button Two tab
		$repeater->end_controls_tabs();		

		$this->add_control(
			'swipeSliders_groups',
			[
				'label' => esc_html__( 'Slider Items', 'proffer-core' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'slider_title' => esc_html__( 'Item #1', 'proffer-core' ),
					],
					
				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ slider_title }}}',
			]
		);		
		$this->end_controls_section();// end: Section

			$this->start_controls_section(
			'social_section_slider',
			[
				'label' => __( 'Slider Social', 'proffer-core' ),
				'condition' => [
					'slide_style' => array('style-one','style-two'),
				],
			]
		);
		$this->add_control(
			'social_title',
			[
				'label' => esc_html__( 'Social title', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'default' => 'Follow us:',
				'placeholder' => esc_html__( 'Type slide title here', 'proffer-core' ),
				'condition' => [
					'slide_style' => array('style-two'),
				],
			]
		);
		$this->add_control(
			'facebook_icon',
			[
				'label' => esc_html__( 'Facebook', 'proffer-core' ),
				'type' => Controls_Manager::ICON,
				'options' => Controls_Helper_Output::get_include_icons(),
				'frontend_available' => true,
				'default' => 'ti-facebook',
				'condition' => [
					'slide_style' => array('style-one','style-two'),
				],
			]
		);
		$this->add_control(
			'facebook_link',
			[
				'label' => esc_html__( 'Facebook Link', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( '#', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type facebook link here', 'proffer-core' ),
				'label_block' => true,
				'condition' => [
					'slide_style' => array('style-one','style-two'),
				],
			]
		);
		$this->add_control(
			'twitter_icon',
			[
				'label' => esc_html__( 'Twitter', 'proffer-core' ),
				'type' => Controls_Manager::ICON,
				'options' => Controls_Helper_Output::get_include_icons(),
				'frontend_available' => true,
				'default' => 'ti-twitter-alt',
				'condition' => [
					'slide_style' => array('style-one','style-two'),
				],
			]
		);
		$this->add_control(
			'twitter_link',
			[
				'label' => esc_html__( 'Twitter Link', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( '#', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type twitter link here', 'proffer-core' ),
				'label_block' => true,
				'condition' => [
					'slide_style' => array('style-one','style-two'),
				],
			]
		);
		$this->add_control(
			'linkedin_icon',
			[
				'label' => esc_html__( 'Linkedin', 'proffer-core' ),
				'type' => Controls_Manager::ICON,
				'options' => Controls_Helper_Output::get_include_icons(),
				'frontend_available' => true,
				'default' => 'ti-linkedin',
				'condition' => [
					'slide_style' => array('style-one','style-two'),
				],
			]
		);
		$this->add_control(
			'linkedin_link',
			[
				'label' => esc_html__( 'Linkedin Link', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( '#', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type linkedin link here', 'proffer-core' ),
				'label_block' => true,
				'condition' => [
					'slide_style' => array('style-one','style-two'),
				],
			]
		);
		$this->add_control(
			'pinterest_icon',
			[
				'label' => esc_html__( 'Pinterest', 'proffer-core' ),
				'type' => Controls_Manager::ICON,
				'options' => Controls_Helper_Output::get_include_icons(),
				'frontend_available' => true,
				'default' => 'ti-pinterest',
				'condition' => [
					'slide_style' => array('style-one','style-two'),
				],
			]
		);
		$this->add_control(
			'pinterest_link',
			[
				'label' => esc_html__( 'Pinterest Link', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( '#', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type pinterest link here', 'proffer-core' ),
				'label_block' => true,
				'condition' => [
					'slide_style' => array('style-one','style-two'),
				],
			]
		);
		$this->end_controls_section();// end: Section

		$this->start_controls_section(
			'section_carousel',
			[
				'label' => esc_html__( 'Carousel Options', 'proffer-core' ),
			]
		);
		$this->add_control(
			'carousel_nav',
			[
				'label' => esc_html__( 'Navigation', 'proffer-core' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'proffer-core' ),
				'label_off' => esc_html__( 'No', 'proffer-core' ),
				'return_value' => 'true',
				'description' => esc_html__( 'If you want Carousel Navigation, enable it.', 'proffer-core' ),
			]
		);
		
		$this->end_controls_section();// end: Section


		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .hero-slider .slide-title h2 ',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hero-slider .slide-title h2' => 'color: {{VALUE}};',
					'{{WRAPPER}} .hero-style-1 .slide-title h2 span' => '-webkit-text-stroke-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'slider_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .hero-slider .slide-text p',
			]
		);
		$this->add_control(
			'slider_content_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hero-slider .slide-text p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section


		// Navigation
		$this->start_controls_section(
			'section_navigation_style',
			[
				'label' => esc_html__( 'Navigation', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'slider_nav_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hero-slider .swiper-button-prev:before,.hero-slider .swiper-button-next:before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'slider_nav_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'slide_style' => array('style-two','style-three' ),
				],
				'selectors' => [
					'{{WRAPPER}} .hero-slider .swiper-button-prev, .hero-slider .swiper-button-next' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Social
		$this->start_controls_section(
			'section_social_style',
			[
				'label' => esc_html__( 'Social', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'slider_social_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hero-slider .social a, .hero-slider .social-container span' => 'color: {{VALUE}};',
					'{{WRAPPER}} .hero-slider .social:before ' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'slider_social_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hero-slider .social a' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Button One Style
		$this->start_controls_section(
			'section_button_style',
			[
				'label' => esc_html__( 'Button One', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .hero-slider .slide-btns .theme-btn-s2',
			]
		);
		$this->add_responsive_control(
			'button_min_width',
			[
				'label' => esc_html__( 'Width', 'proffer-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 500,
						'step' => 1,
					],
				],
				'size_units' => [ 'px' ],
				'selectors' => [
					'{{WRAPPER}} .hero-slider .slide-btns .theme-btn-s2' => 'min-width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'button_padding',
			[
				'label' => __( 'Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .hero-slider .slide-btns .theme-btn-s2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'button_border_radius',
			[
				'label' => __( 'Border Radius', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .hero-slider .slide-btns .theme-btn-s2' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->start_controls_tabs( 'button_style' );
			$this->start_controls_tab(
				'button_normal',
				[
					'label' => esc_html__( 'Normal', 'proffer-core' ),
				]
			);
			$this->add_control(
				'button_color',
				[
					'label' => esc_html__( 'Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-slider .slide-btns .theme-btn-s2' => 'color: {{VALUE}};',
						'{{WRAPPER}} .theme-btn-s2:before' => 'background-color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'button_bg_color',
				[
					'label' => esc_html__( 'Background Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-slider .slide-btns .theme-btn-s2' => 'background-color: {{VALUE}};',
					],
				]
			);
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'button_border',
					'label' => esc_html__( 'Border', 'proffer-core' ),
					'selector' => '{{WRAPPER}} .hero-slider .slide-btns .theme-btn-s2',
				]
			);
			$this->end_controls_tab();  // end:Normal tab
			
			$this->start_controls_tab(
				'button_hover',
				[
					'label' => esc_html__( 'Hover', 'proffer-core' ),
				]
			);
			$this->add_control(
				'button_hover_color',
				[
					'label' => esc_html__( 'Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-slider .slide-btns .theme-btn-s2:hover' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'button_bg_hover_color',
				[
					'label' => esc_html__( 'Background Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-slider .slide-btns .theme-btn-s2:hover' => 'background-color: {{VALUE}};',
					],
				]
			);
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'button_hover_border',
					'label' => esc_html__( 'Border', 'proffer-core' ),
					'selector' => '{{WRAPPER}} .hero-slider .slide-btns .theme-btn-s2:hover',
				]
			);
			$this->end_controls_tab();  // end:Hover tab
		$this->end_controls_tabs(); // end tabs
		
		$this->end_controls_section();// end: Section

		// Button Two
		$this->start_controls_section(
			'section_button_two_style',
			[
				'label' => esc_html__( 'Video Button', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'slide_style' => array('style-one'),
				],
			]
		);
		$this->start_controls_tabs( 'button_two_style' );
			$this->start_controls_tab(
				'button_two_normal',
				[
					'label' => esc_html__( 'Normal', 'proffer-core' ),
				]
			);
			$this->add_control(
				'button_two_color',
				[
					'label' => esc_html__( 'Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-style-1 .video-btns a .fi:before' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'button_two_border_color',
				[
					'label' => esc_html__( 'Border Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-style-1 .video-btns a:after' => 'border-color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'button_two_bg_color',
				[
					'label' => esc_html__( 'Background Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-style-1 .video-btns a' => 'background-color: {{VALUE}};',
					],
				]
			);
			$this->end_controls_tab();  // end:Normal tab
			
			$this->start_controls_tab(
				'button_two_hover',
				[
					'label' => esc_html__( 'Hover', 'proffer-core' ),
				]
			);
			$this->add_control(
				'button_two_hover_color',
				[
					'label' => esc_html__( 'Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} ..hero-style-1 .video-btns a:hover:after' => 'border-color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'button_border_hover_color',
				[
					'label' => esc_html__( 'Border Hover Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-style-1 .video-btns a:hover:before' => 'border-color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'button_two_bg_hover_color',
				[
					'label' => esc_html__( 'Background Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-style-1 .video-btns a:hover' => 'background-color: {{VALUE}};',
					],
				]
			);
			$this->end_controls_tab();  // end:Hover tab
		$this->end_controls_tabs(); // end tabs
		
		$this->end_controls_section();// end: Section


		// Scroll 
		$this->start_controls_section(
			'section_scroll_style',
			[
				'label' => esc_html__( 'Scroll', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'slider_scroll_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hero-style-1 .scroll a i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .hero-style-1 .scroll a' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();// end: Section

		

	
	}

	/**
	 * Render Blog widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();

		// Carousel Options
		$swipeSliders_groups = !empty( $settings['swipeSliders_groups'] ) ? $settings['swipeSliders_groups'] : [];
		$carousel_nav  = ( isset( $settings['carousel_nav'] ) && ( 'true' == $settings['carousel_nav'] ) ) ? true : false;
		$slide_style = !empty( $settings['slide_style'] ) ? $settings['slide_style'] : '';
		$scroll_link = !empty( $settings['scroll_link'] ) ? $settings['scroll_link'] : '';

		$social_title = !empty( $settings['social_title'] ) ? $settings['social_title'] : '';

		$facebook_icon = !empty( $settings['facebook_icon'] ) ? $settings['facebook_icon'] : '';
		$facebook_link = !empty( $settings['facebook_link'] ) ? $settings['facebook_link'] : '';

		$twitter_icon = !empty( $settings['twitter_icon'] ) ? $settings['twitter_icon'] : '';
		$twitter_link = !empty( $settings['twitter_link'] ) ? $settings['twitter_link'] : '';

		$linkedin_icon = !empty( $settings['linkedin_icon'] ) ? $settings['linkedin_icon'] : '';
		$linkedin_link = !empty( $settings['linkedin_link'] ) ? $settings['linkedin_link'] : '';
		
		$pinterest_icon = !empty( $settings['pinterest_icon'] ) ? $settings['pinterest_icon'] : '';
		$pinterest_link = !empty( $settings['pinterest_link'] ) ? $settings['pinterest_link'] : '';

		if ( $slide_style == 'style-one' ) {
			$hero_style = 'hero-style-1';
		} elseif( $slide_style == 'style-two' ) {
			$hero_style = 'hero-style-2';
		} else {
			$hero_style = 'hero-style-3';
		}

		if ( $slide_style == 'style-three' ) {
			$arrow_class = 'pagi-arrow';
			$arrow_next = 'prev';
			$arrow_prev = 'next';
		} else {
			$arrow_class = 'container';
			$arrow_next = 'next';
			$arrow_prev = 'prev';
		}

		// Turn output buffer on
		ob_start();

		 ?>
		<div class="hero-slider <?php echo esc_attr( $hero_style ); ?>">
	    <div class="swiper-container">
	        <div class="swiper-wrapper">
	            <?php
								if( is_array( $swipeSliders_groups ) && !empty( $swipeSliders_groups ) ){
								foreach ( $swipeSliders_groups as $each_item ) {

								$image_url = wp_get_attachment_url( $each_item['slider_image']['id'] );
								$slider_title = !empty( $each_item['slider_title'] ) ? $each_item['slider_title'] : '';
								$slider_content = !empty( $each_item['slider_content'] ) ? $each_item['slider_content'] : '';

								$button_text = !empty( $each_item['btn_txt'] ) ? $each_item['btn_txt'] : '';
								$button_link = !empty( $each_item['button_link']['url'] ) ? $each_item['button_link']['url'] : '';
								$button_link_external = !empty( $each_item['button_link']['is_external'] ) ? 'target="_blank"' : '';
								$button_link_nofollow = !empty( $each_item['button_link']['nofollow'] ) ? 'rel="nofollow"' : '';
								$button_link_attr = !empty( $button_link ) ?  $button_link_external.' '.$button_link_nofollow : '';

								$button_two_link = !empty( $each_item['button_two_link']['url'] ) ? $each_item['button_two_link']['url'] : '';
								$button_two_link_external = !empty( $each_item['button_two_link']['is_external'] ) ? 'target="_blank"' : '';
								$button_two_link_nofollow = !empty( $each_item['button_two_link']['nofollow'] ) ? 'rel="nofollow"' : '';
								$button_two_link_attr = !empty( $button_two_link ) ?  $button_two_link_external.' '.$button_two_link_nofollow : '';


								$button_one = $button_link ? '<a href="'.esc_url($button_link).'" '.$button_link_attr.' class="theme-btn-s2">'. $button_text .'<i class="fi flaticon-heart-1"></i></a>' : '';

								$button_two = $button_two_link ? '<a href="'.esc_url($button_two_link).'" class="video-btn" data-type="iframe"><i class="fi flaticon-play-1"></i></a>' : '';

								$button_actual = ($button_one ) ? '<div data-swiper-parallax="500" class="slide-btns">'.$button_one.'</div>' : '';
								$video_button = ($button_two ) ? '<div class="video-btns">'.$button_two.'</div>' : '';

								?>
	            
	            	<div class="swiper-slide">
	                <div class="slide-inner slide-bg-image" data-background="<?php echo esc_url( $image_url ); ?>">
	                    <div class="container">
	                    	<?php if ( $slider_title  ) { ?>
	                        <div data-swiper-parallax="300" class="slide-title">
	                            <h2><?php echo wp_kses_post( $slider_title ); ?></h2>
	                        </div>
	                      <?php } if ( $slider_content ) { ?>
	                        <div data-swiper-parallax="400" class="slide-text">
	                            <p><?php echo esc_html( $slider_content ); ?></p>
	                        </div>
	                      <?php } ?>
	                        <div class="clearfix"></div>
	                       <?php echo $button_actual.$video_button; ?>
	                    </div>
	                </div> <!-- end slide-inner -->
	            </div><!-- end swiper-slide -->
						<?php }
						} ?>
	        </div>
	        <!-- end swiper-wrapper -->
	        <?php if( $carousel_nav ){ ?>
		        <!-- swipper controls -->
		        <div class="swiper-pagination"></div>
		        <div class="<?php echo esc_attr( $arrow_class ); ?>">
		            <div class="swiper-button-<?php echo esc_attr( $arrow_next ); ?>"></div>
		            <div class="swiper-button-<?php echo esc_attr( $arrow_prev ); ?>"></div>
		        </div>
					<?php } 

					if( $slide_style == 'style-two' ) { echo '<div class="container social-container">'; }  ?>
		        <div class="social">
		        	<?php if( $slide_style == 'style-two' && $social_title ) { echo '<span>'.esc_html( $social_title ).'</span>'; }  ?>
		            <ul>
		              <?php 
		              	if( $facebook_icon ) { echo '<li><a href="'.esc_url( $facebook_link ).'"><i class="'.esc_attr( $facebook_icon ).'"></i></a></li>'; } 
		              	if( $twitter_icon ) { echo '<li><a href="'.esc_url( $twitter_link ).'"><i class="'.esc_attr( $twitter_icon ).'"></i></a></li>'; } 
		              	if( $linkedin_link ) { echo '<li><a href="'.esc_url( $linkedin_link ).'"><i class="'.esc_attr( $linkedin_icon ).'"></i></a></li>'; } 
		              	if( $pinterest_icon ) { echo '<li><a href="'.esc_url( $pinterest_link ).'"><i class="'.esc_attr( $pinterest_icon ).'"></i></a></li>'; } 
		              ?>
		            </ul>
		        </div>
	        <?php if( $slide_style == 'style-two' ) { echo '</div>'; } 
	        if ( $scroll_link ) { ?>
	        	<div class="scroll">
	            	<a href="<?php echo esc_html( $scroll_link ); ?>" id="scroll"><i class="fi flaticon-down-arrow-2"></i></a>
	        	</div>
	       	<?php } ?>
	        
	    </div>
		</div>

		<?php
		// Return outbut buffer
		echo ob_get_clean();
		
	}

	/**
	 * Render Blog widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/

	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_Slider() );
