<?php
/*
 * Elementor Proffer Target Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_Target extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_target';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Target', 'proffer-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-money';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer Target widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['tmx-proffer_target'];
	}
	
	/**
	 * Register Proffer Target widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_target',
			[
				'label' => esc_html__( 'Target Options', 'proffer-core' ),
			]
		);
		$this->add_control(
			'sub_title',
			[
				'label' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Sub Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'target_title',
			[
				'label' => esc_html__( 'Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'target_content',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'default' => esc_html__( 'your content text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type your content here', 'proffer-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$this->add_control(
			'btn_text',
			[
				'label' => esc_html__( 'Button Text', 'proffer-core' ),
				'default' => esc_html__( 'button text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type button Text here', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		$this->add_control(
			'btn_link',
			[
				'label' => esc_html__( 'Button Link', 'proffer-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'https://your-link.com',
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);
		$this->add_control(
			'target_image',
			[
				'label' => esc_html__( 'Target Image', 'proffer-core' ),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__( 'Set your image.', 'proffer-core'),
			]
		);
		
		$this->add_control(
			'goal_title',
			[
				'label' => esc_html__( 'Goal Title', 'proffer-core' ),
				'default' => esc_html__( 'Donation goal', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type your Title here', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		$this->add_control(
			'goal_amount',
			[
				'label' => esc_html__( 'Goal Amount', 'proffer-core' ),
				'default' => esc_html__( '$45,000', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type your Amount here', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		$this->add_control(
			'raised_title',
			[
				'label' => esc_html__( 'Raised  Title', 'proffer-core' ),
				'default' => esc_html__( 'Donation raised', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type your Title here', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		$this->add_control(
			'raised_amount',
			[
				'label' => esc_html__( 'Raised  Amount', 'proffer-core' ),
				'default' => esc_html__( '$35,000', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type your Amount here', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
	 $this->end_controls_section();// end: Section


		// Sub Title
		$this->start_controls_section(
			'section_subtitle_style',
			[
				'label' => esc_html__( 'Sub Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'sub_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .proffer-target .section-title span',
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .proffer-target .section-title span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'subtitle_padding',
			[
				'label' => __( 'Sub Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .proffer-target .section-title span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section
	
		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .proffer-target .section-title h2',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .proffer-target .section-title h2' => 'color: {{VALUE}};',
					'{{WRAPPER}} .proffer-target .section-title h2 span' => '-webkit-text-stroke-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .proffer-target .section-title h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'section_content_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .proffer-target .content p',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .proffer-target .content p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

	
		// Button One
		$this->start_controls_section(
			'section_button_style',
			[
				'label' => esc_html__( 'Button One', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_one_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .proffer-target .target-content .theme-btn-s3',
			]
		);
		
		$this->start_controls_tabs( 'button_one_style' );
			$this->start_controls_tab(
				'button_one_normal',
				[
					'label' => esc_html__( 'Normal', 'proffer-core' ),
				]
			);
			$this->add_control(
				'button_one_color',
				[
					'label' => esc_html__( 'Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .proffer-target .target-content .theme-btn-s3' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'button_one_bgcolor',
				[
					'label' => esc_html__( 'Background Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .proffer-target .target-content .theme-btn-s3' => 'background-color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
			'button_padding',
				[
					'label' => __( 'Padding', 'proffer-core' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em' ],
					'selectors' => [
						'{{WRAPPER}} .proffer-target .target-content .theme-btn-s3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
			$this->end_controls_tab();  // end:Normal tab
			
			$this->start_controls_tab(
				'button_one_hover',
				[
					'label' => esc_html__( 'Hover', 'proffer-core' ),
				]
			);
			$this->add_control(
				'button_one_hover_color',
				[
					'label' => esc_html__( 'Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .proffer-target .target-content .theme-btn-s3:hover' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'button_one_hover_bg_color',
				[
					'label' => esc_html__( 'Background Color', 'proffer-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .proffer-target .target-content .theme-btn-s3:hover' => 'background-color: {{VALUE}};',
					],
				]
			);
			$this->end_controls_tab();  // end:Hover tab
		$this->end_controls_tabs(); // end tabs
		
		$this->end_controls_section();// end: Section


		// Info Title
		$this->start_controls_section(
			'section_info_title_style',
			[
				'label' => esc_html__( 'Info Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_info_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .target-area .goal-raised span',
			]
		);
		$this->add_control(
			'info_title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .target-area .goal-raised span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'info_title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .target-area .goal-raised span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section


		// Info Name
		$this->start_controls_section(
			'section_info_name_style',
			[
				'label' => esc_html__( 'Info Amount', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_info_name_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .target-area .goal-raised h3',
			]
		);
		$this->add_control(
			'info_name_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .target-area .goal-raised h3' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'info_name_padding',
			[
				'label' => esc_html__( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .target-area .goal-raised h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

	}

	/**
	 * Render Target widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();

		$sub_title = !empty( $settings['sub_title'] ) ? $settings['sub_title'] : '';
		$target_title = !empty( $settings['target_title'] ) ? $settings['target_title'] : '';
		$target_content = !empty( $settings['target_content'] ) ? $settings['target_content'] : '';

		$goal_title = !empty( $settings['goal_title'] ) ? $settings['goal_title'] : '';
		$goal_amount = !empty( $settings['goal_amount'] ) ? $settings['goal_amount'] : '';

		$raised_title = !empty( $settings['raised_title'] ) ? $settings['raised_title'] : '';
		$raised_amount = !empty( $settings['raised_amount'] ) ? $settings['raised_amount'] : '';

		$bg_image = !empty( $settings['target_image']['id'] ) ? $settings['target_image']['id'] : '';	

		$button_text = !empty( $settings['btn_text'] ) ? $settings['btn_text'] : '';	
		$button_link = !empty( $settings['btn_link']['url'] ) ? $settings['btn_link']['url'] : '';
		$button_link_external = !empty( $settings['btn_link']['is_external'] ) ? 'target="_blank"' : '';
		$button_link_nofollow = !empty( $settings['btn_link']['nofollow'] ) ? 'rel="nofollow"' : '';
		$button_link_attr = !empty( $button_link ) ?  $button_link_external.' '.$button_link_nofollow : '';
  
		// Image
		$image_url = wp_get_attachment_url( $bg_image );
		$image_alt = get_post_meta( $settings['target_image']['id'], '_wp_attachment_image_alt', true);

		$proffer_button = $button_link ? '<a href="'.esc_url($button_link).'" '.$button_link_attr.' class="theme-btn-s3">'.esc_html( $button_text ).'<i class="fi flaticon-like"></i></a>' : '';
	

		// Turn output buffer on
		ob_start(); ?>
		<div class="proffer-target target-area">
	    <div class="row">
	        <div class="col col-md-5">
	            <div class="img-holder">
	                <?php if( $image_url ) { echo '<img src="'.esc_url( $image_url ).'" alt="'.esc_url( $image_alt ).'">'; } ?>
	            </div>
	        </div>
	        <div class="col col-md-7">
	            <div class="target-content">
	                <div class="section-title">
	                   <?php 
	                    if( $sub_title ) { echo '<span>'.esc_html( $sub_title ).'</span>'; } 
			                if( $target_title ) { echo '<h2>'.wp_kses_post( $target_title ).'</h2>'; } 
			               ?>
	                </div>
	                <div class="content">
	                    <?php if( $target_content ) { echo '<P>'.esc_html( $target_content ).'</P>'; } ?>
	                    <div class="goal-raised">
	                        <div>
	                        	<?php 
					                    if( $goal_title ) { echo '<span>'.esc_html( $goal_title ).'</span>'; } 
							                if( $goal_amount ) { echo '<h3>'.esc_html( $goal_amount ).'</h3>'; } 
							               ?>
	                        </div>
	                        <div>
	                           <?php 
					                    if( $raised_title ) { echo '<span>'.esc_html( $raised_title ).'</span>'; } 
							                if( $raised_amount ) { echo '<h3>'.esc_html( $raised_amount ).'</h3>'; } 
							               ?>
	                        </div>
	                    </div>
	                    <?php echo $proffer_button; ?>
	                </div>
	            </div>
	        </div>
	    </div>
		</div>

		<?php // Return outbut buffer
			echo ob_get_clean();	
		}
	/**
	 * Render Target widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_Target() );