<?php
/*
 * Elementor Proffer Team Widget
 * Author & Copyright: themexshaper
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Proffer_Team extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'tmx-proffer_team';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Team', 'proffer-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['themexshaper-category'];
	}

	/**
	 * Retrieve the list of scripts the Proffer Team widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	public function get_script_depends() {
		return ['tmx-proffer_team'];
	}
	
	/**
	 * Register Proffer Team widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){


		$posts = get_posts( 'post_type="team"&numberposts=-1' );
    $PostID = array();
    if ( $posts ) {
      foreach ( $posts as $post ) {
        $PostID[ $post->ID ] = $post->ID;
      }
    } else {
      $PostID[ __( 'No ID\'s found', 'proffer' ) ] = 0;
    }

		$this->start_controls_section(
			'section_team_listing',
			[
				'label' => esc_html__( 'Team Options', 'proffer-core' ),
			]
		);
		$this->add_control(
			'sub_title',
			[
				'label' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Sub Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Sub Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'section_title',
			[
				'label' => esc_html__( 'Title Text', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'proffer-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'proffer-core' ),
				'default' => esc_html__( 'your content text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type your content here', 'proffer-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$this->add_control(
			'btn_text',
			[
				'label' => esc_html__( 'Button Text', 'proffer-core' ),
				'default' => esc_html__( 'button text', 'proffer-core' ),
				'placeholder' => esc_html__( 'Type button Text here', 'proffer-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		$this->add_control(
			'btn_link',
			[
				'label' => esc_html__( 'Button Link', 'proffer-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'https://your-link.com',
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);
		$this->add_control(
			'team_limit',
			[
				'label' => esc_html__( 'Team Limit', 'proffer-core' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 100,
				'step' => 1,
				'default' => 3,
				'description' => esc_html__( 'Enter the number of items to show.', 'proffer-core' ),
			]
		);
		$this->add_control(
			'team_order',
			[
				'label' => __( 'Order', 'proffer-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'ASC' => esc_html__( 'Asending', 'proffer-core' ),
					'DESC' => esc_html__( 'Desending', 'proffer-core' ),
				],
				'default' => 'DESC',
			]
		);
		$this->add_control(
			'team_orderby',
			[
				'label' => __( 'Order By', 'proffer-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'None', 'proffer-core' ),
					'ID' => esc_html__( 'ID', 'proffer-core' ),
					'author' => esc_html__( 'Author', 'proffer-core' ),
					'title' => esc_html__( 'Title', 'proffer-core' ),
					'date' => esc_html__( 'Date', 'proffer-core' ),
				],
				'default' => 'date',
			]
		);
		$this->add_control(
			'team_show_category',
			[
				'label' => __( 'Certain Categories?', 'proffer-core' ),
				'type' => Controls_Manager::SELECT2,
				'default' => [],
				'options' => Controls_Helper_Output::get_terms_names( 'team_category'),
				'multiple' => true,
			]
		);
		$this->add_control(
			'team_show_id',
			[
				'label' => __( 'Certain ID\'s?', 'proffer-core' ),
				'type' => Controls_Manager::SELECT2,
				'default' => [],
				'options' => $PostID,
				'multiple' => true,
			]
		);
		$this->end_controls_section();// end: Section


		// Subtitle
		$this->start_controls_section(
			'section_subtitle_style',
			[
				'label' => esc_html__( 'Subtitle', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-section .section-title span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'subtitle_padding',
			[
				'label' => esc_html__( 'Subtitle Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .team-section .section-title span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .team-section .section-title h2',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-section .section-title h2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'proffer-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .team-section .section-title h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();// end: Section
		
		// Content
		$this->start_controls_section(
			'section_content_icon_style',
			[
				'label' => esc_html__( 'Icon', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'team_icon_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-section .team-details p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'team_icon_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-section .team-details p' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Button
		$this->start_controls_section(
			'section_content_btn_style',
			[
				'label' => esc_html__( 'Button', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_btn_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .team-section .team-details .theme-btn-s4',
			]
		);
		$this->add_control(
			'team_btn_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-section .team-details .theme-btn-s4' => 'color: {{VALUE}};',
					'{{WRAPPER}} .team-section .team-details .theme-btn-s4:before' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Team Title
		$this->start_controls_section(
			'section_team_info_style',
			[
				'label' => esc_html__( 'Team Info', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'team_team_info_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-section .member-info' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Team Title
		$this->start_controls_section(
			'section_team_title_style',
			[
				'label' => esc_html__( 'Team Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_team_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .team-section .member-info h4 a',
			]
		);
		$this->add_control(
			'team_team_title_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-section .member-info h4 a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Team Subtitle
		$this->start_controls_section(
			'section_team_subtitle_style',
			[
				'label' => esc_html__( 'Team Sub Title', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_team_subtitle_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .team-section .member-info p',
			]
		);
		$this->add_control(
			'team_team_subtitle_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-section .member-info p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Team Icon
		$this->start_controls_section(
			'section_team_icon_style',
			[
				'label' => esc_html__( 'Team Icon', 'proffer-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'proffer-core' ),
				'name' => 'proffer_team_icon_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .team-section .member-info ul a',
			]
		);
		$this->add_control(
			'team_team_icon_color',
			[
				'label' => esc_html__( 'Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-section .member-info ul a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'team_team_icon_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'proffer-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-section .member-info ul a' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		
	}

	/**
	 * Render Team widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();

		$team_limit = !empty( $settings['team_limit'] ) ? $settings['team_limit'] : '';
		$team_order = !empty( $settings['team_order'] ) ? $settings['team_order'] : '';
		$team_orderby = !empty( $settings['team_orderby'] ) ? $settings['team_orderby'] : '';
		$team_show_category = !empty( $settings['team_show_category'] ) ? $settings['team_show_category'] : [];
		$team_show_id = !empty( $settings['team_show_id'] ) ? $settings['team_show_id'] : [];

		$sub_title = !empty( $settings['sub_title'] ) ? $settings['sub_title'] : '';
		$section_title = !empty( $settings['section_title'] ) ? $settings['section_title'] : '';
		$section_content = !empty( $settings['section_content'] ) ? $settings['section_content'] : '';

		$button_text = !empty( $settings['btn_text'] ) ? $settings['btn_text'] : '';	
		$button_link = !empty( $settings['btn_link']['url'] ) ? $settings['btn_link']['url'] : '';
		$button_link_external = !empty( $settings['btn_link']['is_external'] ) ? 'target="_blank"' : '';
		$button_link_nofollow = !empty( $settings['btn_link']['nofollow'] ) ? 'rel="nofollow"' : '';
		$button_link_attr = !empty( $button_link ) ?  $button_link_external.' '.$button_link_nofollow : '';
  
		$proffer_button = $button_link ? '<a href="'.esc_url($button_link).'" '.$button_link_attr.' class="theme-btn-s4">'.esc_html( $button_text ).'</a>' : '';


		// Turn output buffer on
		ob_start();

		// Pagination
		global $paged;
		if( get_query_var( 'paged' ) )
		  $my_page = get_query_var( 'paged' );
		else {
		  if( get_query_var( 'page' ) )
			$my_page = get_query_var( 'page' );
		  else
			$my_page = 1;
		  set_query_var( 'paged', $my_page );
		  $paged = $my_page;
		}

    if ($team_show_id) {
			$team_show_id = json_encode( $team_show_id );
			$team_show_id = str_replace(array( '[', ']' ), '', $team_show_id);
			$team_show_id = str_replace(array( '"', '"' ), '', $team_show_id);
      $team_show_id = explode(',',$team_show_id);
    } else {
      $team_show_id = '';
    }

		$args = array(
		  // other query params here,
		  'paged' => $my_page,
		  'post_type' => 'team',
		  'posts_per_page' => (int)$team_limit,
		  'category_name' => implode(',', $team_show_category),
		  'orderby' => $team_orderby,
		  'order' => $team_order,
      'post__in' => $team_show_id,
		);

		$proffer_team = new \WP_Query( $args );
		if ( $proffer_team->have_posts()) :
		?>
			<div class="team-section">
			    <div class="content-area">
			        <div class="first-row clearfix">
			            <div class="grid"></div>
			            <div class="grid info-grid">
			                <div class="section-title">
			                	 <?php 
		                    	if( $sub_title ) { echo '<span>'.esc_html( $sub_title ).'</span>'; } 
				                  if( $section_title ) { echo '<h2>'.esc_html( $section_title ).'</h2>'; } 
		                    ?>
			                </div>
			                <div class="team-details">
			                	<?php
			                		 if( $section_content ) { echo '<p>'.esc_html( $section_content ).'</p>'; } 
			                		 echo $proffer_button;
			                	 ?>
			                </div>
			            </div>
			            <?php 
			             $team_count = 0;
									 while ( $proffer_team->have_posts()) : $proffer_team->the_post();
										$team_count++;
										$team_options = get_post_meta( get_the_ID(), 'team_options', true );
										$team_title = isset( $team_options['team_title']) ? $team_options['team_title'] : '';
										$team_subtitle = isset( $team_options['team_subtitle']) ? $team_options['team_subtitle'] : '';
										$team_image = isset( $team_options['team_image']) ? $team_options['team_image'] : '';
										$team_socials = isset($team_options['team_socials']) ? $team_options['team_socials'] : '';
										global $post;
										$image_url = wp_get_attachment_url( $team_image );
										$image_alt = get_post_meta( $team_image , '_wp_attachment_image_alt', true);

									if (  $team_count == 1 || $team_count == 2 ) {  ?>
 									<div class="grid">
			                <div class="img-holder">
			                   <?php if( $image_url ) { echo '<img src="'.esc_url( $image_url ).'" alt="'.esc_attr( $image_alt ).'">'; } ?>
			                </div>
			                <div class="member-info">
			                    <?php 
						            		if( $team_title) { echo '<h4><a href="'.esc_url( get_permalink() ).'">'.esc_html( $team_title ).'</a></h4>'; }
						            		if( $team_subtitle ) { echo '<p>'.esc_html( $team_subtitle ).'</p>'; }
						            	?>
			                    <ul>
			                      <?php foreach ( $team_socials as $key => $team_social ) {
													    echo'<li><a href="'.esc_url( $team_social['team_social_link'] ).'"><i class="'.esc_attr( $team_social['team_social_icon']  ).'" ></i></a></li>';
													  } ?>
			                    </ul>
			                </div>
			            </div>
									<?php } 
								  endwhile;
								  wp_reset_postdata();
								 ?>
			        </div>

			        <div class="sec-row clearfix">
			         		<?php 
			         		 $team_count = 0;
									 while ( $proffer_team->have_posts()) : $proffer_team->the_post();
										$team_count++;
										$team_options = get_post_meta( get_the_ID(), 'team_options', true );
										$team_title = isset( $team_options['team_title']) ? $team_options['team_title'] : '';
										$team_subtitle = isset( $team_options['team_subtitle']) ? $team_options['team_subtitle'] : '';
										$team_image = isset( $team_options['team_image']) ? $team_options['team_image'] : '';
										$team_socials = isset($team_options['team_socials']) ? $team_options['team_socials'] : '';
										global $post;
										$image_url = wp_get_attachment_url( $team_image );
										$image_alt = get_post_meta( $team_image , '_wp_attachment_image_alt', true);

									if ( $team_count !== 1 && $team_count !== 2 ) {  ?>
			            <div class="grid">
			                <div class="img-holder">
			                   <?php if( $image_url ) { echo '<img src="'.esc_url( $image_url ).'" alt="'.esc_attr( $image_alt ).'">'; } ?>
			                </div>
			                <div class="member-info">
			                    <?php 
						            		if( $team_title) { echo '<h4><a href="'.esc_url( get_permalink() ).'">'.esc_html( $team_title ).'</a></h4>'; }
						            		if( $team_subtitle ) { echo '<p>'.esc_html( $team_subtitle ).'</p>'; }
						            	?>
			                    <ul>
			                      <?php foreach ( $team_socials as $key => $team_social ) {
													    echo'<li><a href="'.esc_url( $team_social['team_social_link'] ).'"><i class="'.esc_attr( $team_social['team_social_icon']  ).'" ></i></a></li>';
													  } ?>
			                    </ul>
			                </div>
			            </div>
			            <?php }
								  endwhile;
								  wp_reset_postdata();
								 ?>
			        </div>
			        
			    </div> <!-- end content-area -->
			</div>
			<?php
			 endif;
			// Return outbut buffer
			echo ob_get_clean();	
		}
	/**
	 * Render Team widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Proffer_Team() );