<?php
/*
 * All Theme Options for Proffer theme.
 * Author & Copyright:themexshaper
 * URL: http://themeforest.net/user/themexshaper
 */

function proffer_settings( $settings ) {

  $settings           = array(
    'menu_title'      => PROFFER_NAME . esc_html__(' Options', 'proffer'),
    'menu_slug'       => sanitize_title(PROFFER_NAME) . '_options',
    'menu_type'       => 'theme',
    'menu_icon'       => 'dashicons-awards',
    'menu_position'   => '4',
    'ajax_save'       => false,
    'show_reset_all'  => true,
    'framework_title' => PROFFER_NAME .' <small>V-'. PROFFER_VERSION .' by <a href="'. PROFFER_BRAND_URL .'" target="_blank">'. PROFFER_BRAND_NAME .'</a></small>',
  );

  return $settings;

}
add_filter( 'cs_framework_settings', 'proffer_settings' );

// Theme Framework Options
function proffer_options( $options ) {

  $options      = array(); // remove old options

  // ------------------------------
  // Branding
  // ------------------------------
  $options[]   = array(
    'name'     => 'proffer_theme_branding',
    'title'    => esc_html__('Brand', 'proffer'),
    'icon'     => 'fa fa-trophy',
    'sections' => array(

      // brand logo tab
      array(
        'name'     => 'brand_logo',
        'title'    => esc_html__('Logo', 'proffer'),
        'icon'     => 'fa fa-star',
        'fields'   => array(

          // Site Logo
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Site Logo', 'proffer')
          ),
          array(
            'id'    => 'proffer_logo',
            'type'  => 'image',
            'title' => esc_html__('Default Logo', 'proffer'),
            'info'  => esc_html__('Upload your default logo here. If you not upload, then site title will load in this logo location.', 'proffer'),
            'add_title' => esc_html__('Add Logo', 'proffer'),
          ),
          array(
            'id'    => 'proffer_trlogo',
            'type'  => 'image',
            'title' => esc_html__('Logo Style 2', 'proffer'),
            'info'  => esc_html__('Upload your Transparent logo here. If you not upload, then site title will load in this logo location.', 'proffer'),
            'add_title' => esc_html__('Add Logo', 'proffer'),
          ),
          array(
            'id'    => 'proffer_logo_s2',
            'type'  => 'image',
            'title' => esc_html__('Logo Style 3', 'proffer'),
            'info'  => esc_html__('Upload your Transparent logo here. If you not upload, then site title will load in this logo location.', 'proffer'),
            'add_title' => esc_html__('Add Logo', 'proffer'),
          ),
          array(
            'id'          => 'proffer_logo_top',
            'type'        => 'number',
            'title'       => esc_html__('Logo Top Space', 'proffer'),
            'attributes'  => array( 'placeholder' => 5 ),
            'unit'        => 'px',
          ),
          array(
            'id'          => 'proffer_logo_bottom',
            'type'        => 'number',
            'title'       => esc_html__('Logo Bottom Space', 'proffer'),
            'attributes'  => array( 'placeholder' => 5 ),
            'unit'        => 'px',
          ),
          // WordPress Admin Logo
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('WordPress Admin Logo', 'proffer')
          ),
          array(
            'id'    => 'brand_logo_wp',
            'type'  => 'image',
            'title' => esc_html__('Login logo', 'proffer'),
            'info'  => esc_html__('Upload your WordPress login page logo here.', 'proffer'),
            'add_title' => esc_html__('Add Login Logo', 'proffer'),
          ),
        ) // end: fields
      ), // end: section
    ),
  );

  // ------------------------------
  // Layout
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_layout',
    'title'  => esc_html__('Layout', 'proffer'),
    'icon'   => 'fa fa-file-text'
  );

  $options[]      = array(
    'name'        => 'theme_general',
    'title'       => esc_html__('General', 'proffer'),
    'icon'        => 'fa fa-wrench',

    // begin: fields
    'fields'      => array(

      // -----------------------------
      // Begin: Responsive
      // -----------------------------
       array(
        'id'    => 'theme_responsive',
        'off_text'  => 'No',
        'on_text'  => 'Yes',
        'type'  => 'switcher',
        'title' => esc_html__('Responsive', 'proffer'),
        'info' => esc_html__('Turn on if you don\'t want your site to be responsive.', 'proffer'),
        'default' => false,
      ),
      array(
        'id'    => 'theme_preloder',
        'off_text'  => 'No',
        'on_text'  => 'Yes',
        'type'  => 'switcher',
        'title' => esc_html__('Preloder', 'proffer'),
        'info' => esc_html__('Turn off if you don\'t want your site to be Preloder.', 'proffer'),
        'default' => true,
      ),
      array(
        'id'    => 'theme_layout_width',
        'type'  => 'image_select',
        'title' => esc_html__('Full Width & Extra Width', 'proffer'),
        'info' => esc_html__('Boxed or Fullwidth? Choose your site layout width. Default : Full Width', 'proffer'),
        'options'      => array(
          'container'    => PROFFER_CS_IMAGES .'/boxed-width.jpg',
          'container-fluid'    => PROFFER_CS_IMAGES .'/full-width.jpg',
        ),
        'default'      => 'container-fluid',
        'radio'      => true,
      ),
       array(
        'id'    => 'theme_page_comments',
        'type'  => 'switcher',
        'title' => esc_html__('Hide Page Comments?', 'proffer'),
        'label' => esc_html__('Yes! Hide Page Comments.', 'proffer'),
        'on_text' => esc_html__('Yes', 'proffer'),
        'off_text' => esc_html__('No', 'proffer'),
        'default' => false,
      ),
      array(
        'type'    => 'notice',
        'class'   => 'info cs-proffer-heading',
        'content' => esc_html__('Background Options', 'proffer'),
        'dependency' => array( 'theme_layout_width_container', '==', 'true' ),
      ),
      array(
        'id'             => 'theme_layout_bg_type',
        'type'           => 'select',
        'title'          => esc_html__('Background Type', 'proffer'),
        'options'        => array(
          'bg-image' => esc_html__('Image', 'proffer'),
          'bg-pattern' => esc_html__('Pattern', 'proffer'),
        ),
        'dependency' => array( 'theme_layout_width_container', '==', 'true' ),
      ),
      array(
        'id'    => 'theme_layout_bg_pattern',
        'type'  => 'image_select',
        'title' => esc_html__('Background Pattern', 'proffer'),
        'info' => esc_html__('Select background pattern', 'proffer'),
        'options'      => array(
          'pattern-1'    => PROFFER_CS_IMAGES . '/pattern-1.png',
          'pattern-2'    => PROFFER_CS_IMAGES . '/pattern-2.png',
          'pattern-3'    => PROFFER_CS_IMAGES . '/pattern-3.png',
          'pattern-4'    => PROFFER_CS_IMAGES . '/pattern-4.png',
          'custom-pattern'  => PROFFER_CS_IMAGES . '/pattern-5.png',
        ),
        'default'      => 'pattern-1',
        'radio'      => true,
        'dependency' => array( 'theme_layout_width_container|theme_layout_bg_type', '==|==', 'true|bg-pattern' ),
      ),
      array(
        'id'      => 'custom_bg_pattern',
        'type'    => 'upload',
        'title'   => esc_html__('Custom Pattern', 'proffer'),
        'dependency' => array( 'theme_layout_width_container|theme_layout_bg_type|theme_layout_bg_pattern_custom-pattern', '==|==|==', 'true|bg-pattern|true' ),
        'info' => __('Select your custom background pattern. <br />Note, background pattern image will be repeat in all x and y axis. So, please consider all repeatable area will perfectly fit your custom patterns.', 'proffer'),
      ),
      array(
        'id'      => 'theme_layout_bg',
        'type'    => 'background',
        'title'   => esc_html__('Background', 'proffer'),
        'dependency' => array( 'theme_layout_width_container|theme_layout_bg_type', '==|==', 'true|bg-image' ),
      ),

    ), // end: fields

  );

  // ------------------------------
  // Header Sections
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_header_tab',
    'title'    => esc_html__('Header', 'proffer'),
    'icon'     => 'fa fa-bars',
    'sections' => array(

      // header design tab
      array(
        'name'     => 'header_design_tab',
        'title'    => esc_html__('Design', 'proffer'),
        'icon'     => 'fa fa-magic',
        'fields'   => array(

          // Header Select
          array(
            'id'           => 'select_header_design',
            'type'         => 'image_select',
            'title'        => esc_html__('Select Header Design', 'proffer'),
            'options'      => array(
              'style_one'    => PROFFER_CS_IMAGES .'/hs-1.png',
              'style_two'    => PROFFER_CS_IMAGES .'/hs-2.png',
              'style_three'    => PROFFER_CS_IMAGES .'/hs-3.png',
            ),
            'attributes' => array(
              'data-depend-id' => 'header_design',
            ),
            'radio'        => true,
            'default'   => 'style_one',
            'info' => esc_html__('Select your header design, following options will may differ based on your selection of header design.', 'proffer'),
          ),
          // Header Select

          // Extra's
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Extra\'s', 'proffer'),
          ),
          array(
            'id'    => 'sticky_header',
            'type'  => 'switcher',
            'title' => esc_html__('Sticky Header', 'proffer'),
            'info' => esc_html__('Turn On if you want your naviagtion bar on sticky.', 'proffer'),
            'default' => true,
          ),
          array(
            'id'    => 'proffer_cart_widget',
            'type'  => 'switcher',
            'title' => esc_html__('Header Cart', 'proffer'),
            'info' => esc_html__('Turn On if you want to Show Header Cart .', 'proffer'),
            'default' => false,
          ),
          array(
            'id'    => 'proffer_header_search',
            'type'  => 'switcher',
            'title' => esc_html__('Header Search', 'proffer'),
            'info' => esc_html__('Turn On if you want to Show Header Search .', 'proffer'),
            'default' => false,
          ),
          array(
            'id'    => 'proffer_menu_cta',
            'type'  => 'switcher',
            'title' => esc_html__('Header CTA', 'proffer'),
            'info' => esc_html__('Turn On if you want to Show Header CTA .', 'proffer'),
            'default' => false,
          ),
          array(
            'id'    => 'cta_text',
            'type'  => 'text',
            'title' => esc_html__('CTA text', 'proffer'),
            'info' => esc_html__('Write Header navigation Bar Cal To Action here.', 'proffer'),
            'default' => ' Donate Now',
            'dependency'  => array('proffer_menu_cta', '==', true),
          ),
          array(
            'id'    => 'cta_link',
            'type'  => 'text',
            'title' => esc_html__('CTA link', 'proffer'),
            'info' => esc_html__('Write Header navigation Bar Cal To Action Link here.', 'proffer'),
            'default' => '#',
            'dependency'  => array('proffer_menu_cta', '==', true),
          ),
        )
      ),

      // header top bar
      array(
        'name'     => 'header_top_bar_tab',
        'title'    => esc_html__('Top Bar', 'proffer'),
        'icon'     => 'fa fa-minus',
        'fields'   => array(

          array(
            'id'          => 'top_bar',
            'type'        => 'switcher',
            'title'       => esc_html__('Hide Top Bar', 'proffer'),
            'on_text'     => esc_html__('Yes', 'proffer'),
            'off_text'    => esc_html__('No', 'proffer'),
            'default'     => true,
          ),
          array(
            'id'          => 'top_left',
            'title'       => esc_html__('Top left Block', 'proffer'),
            'desc'        => esc_html__('Top bar left block.', 'proffer'),
            'type'        => 'textarea',
            'shortcode'   => true,
            'dependency'  => array('top_bar', '==', false),
          ),
          array(
            'id'          => 'top_right',
            'title'       => esc_html__('Top Right Block', 'proffer'),
            'desc'        => esc_html__('Top bar right block.', 'proffer'),
            'type'        => 'textarea',
            'shortcode'   => true,
            'dependency'  => array('top_bar', '==', false),
          ),
        )
      ),

      // header banner
      array(
        'name'     => 'header_banner_tab',
        'title'    => esc_html__('Title Bar (or) Banner', 'proffer'),
        'icon'     => 'fa fa-bullhorn',
        'fields'   => array(

          // Title Area
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Title Area', 'proffer')
          ),
          array(
            'id'      => 'need_title_bar',
            'type'    => 'switcher',
            'title'   => esc_html__('Title Bar ?', 'proffer'),
            'label'   => esc_html__('If you want to Hide title bar in your sub-pages, please turn this ON.', 'proffer'),
            'default'    => false,
          ),
          array(
            'id'             => 'title_bar_padding',
            'type'           => 'select',
            'title'          => esc_html__('Padding Spaces Top & Bottom', 'proffer'),
            'options'        => array(
              'padding-default' => esc_html__('Default Spacing', 'proffer'),
              'padding-custom' => esc_html__('Custom Padding', 'proffer'),
            ),
            'dependency'   => array( 'need_title_bar', '==', 'false' ),
          ),
          array(
            'id'             => 'titlebar_top_padding',
            'type'           => 'text',
            'title'          => esc_html__('Padding Top', 'proffer'),
            'attributes' => array(
              'placeholder'     => '100px',
            ),
            'dependency'   => array( 'title_bar_padding', '==', 'padding-custom' ),
          ),
          array(
            'id'             => 'titlebar_bottom_padding',
            'type'           => 'text',
            'title'          => esc_html__('Padding Bottom', 'proffer'),
            'attributes' => array(
              'placeholder'     => '100px',
            ),
            'dependency'   => array( 'title_bar_padding', '==', 'padding-custom' ),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Background Options', 'proffer'),
            'dependency' => array( 'need_title_bar', '==', 'false' ),
          ),
          array(
            'id'      => 'titlebar_bg_overlay_color',
            'type'    => 'color_picker',
            'title'   => esc_html__('Overlay Color', 'proffer'),
            'dependency' => array( 'need_title_bar', '==', 'false' ),
          ),
          array(
            'id'    => 'title_color',
            'type'  => 'color_picker',
            'title' => esc_html__('Title Color', 'proffer'),
            'dependency'   => array('banner_type', '==', 'default-title'),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Breadcrumbs', 'proffer'),
          ),
         array(
            'id'      => 'need_breadcrumbs',
            'type'    => 'switcher',
            'title'   => esc_html__('Hide Breadcrumbs', 'proffer'),
            'label'   => esc_html__('If you want to hide breadcrumbs in your banner, please turn this ON.', 'proffer'),
            'default'    => false,
          ),
        )
      ),

    ),
  );

  // ------------------------------
  // Footer Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'footer_section',
    'title'    => esc_html__('Footer', 'proffer'),
    'icon'     => 'fa fa-ellipsis-h',
    'sections' => array(

      // footer widgets
      array(
        'name'     => 'footer_widgets_tab',
        'title'    => esc_html__('Widget Area', 'proffer'),
        'icon'     => 'fa fa-th',
        'fields'   => array(

          // Footer Widget Block
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Footer Widget Block', 'proffer')
          ),
          array(
            'id'    => 'footer_widget_block',
            'type'  => 'switcher',
            'title' => esc_html__('Enable Widget Block', 'proffer'),
            'info' => __('If you turn this ON, then Goto : Appearance > Widgets. There you can see <strong>Footer Widget 1,2,3 or 4</strong> Widget Area, add your widgets there.', 'proffer'),
            'default' => true,
          ),
          array(
            'id'    => 'footer_widget_layout',
            'type'  => 'image_select',
            'title' => esc_html__('Widget Layouts', 'proffer'),
            'info' => esc_html__('Choose your footer widget theme-layouts.', 'proffer'),
            'default' => 4,
            'options' => array(
              1   => PROFFER_CS_IMAGES . '/footer/footer-1.png',
              2   => PROFFER_CS_IMAGES . '/footer/footer-2.png',
              3   => PROFFER_CS_IMAGES . '/footer/footer-3.png',
              4   => PROFFER_CS_IMAGES . '/footer/footer-4.png',
              5   => PROFFER_CS_IMAGES . '/footer/footer-5.png',
              6   => PROFFER_CS_IMAGES . '/footer/footer-6.png',
              7   => PROFFER_CS_IMAGES . '/footer/footer-7.png',
              8   => PROFFER_CS_IMAGES . '/footer/footer-8.png',
              9   => PROFFER_CS_IMAGES . '/footer/footer-9.png',
            ),
            'radio'       => true,
            'dependency'  => array('footer_widget_block', '==', true),
          ),
           array(
            'id'    => 'proffer_ft_bg',
            'type'  => 'image',
            'title' => esc_html__('Footer Background', 'proffer'),
            'info'  => esc_html__('Upload your footer background.', 'proffer'),
            'add_title' => esc_html__('footer background', 'proffer'),
            'dependency'  => array('footer_widget_block', '==', true),
          ),

        )
      ),

      // footer copyright
      array(
        'name'     => 'footer_copyright_tab',
        'title'    => esc_html__('Copyright Bar', 'proffer'),
        'icon'     => 'fa fa-copyright',
        'fields'   => array(

          // Copyright
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Copyright Layout', 'proffer'),
          ),
         array(
            'id'    => 'hide_copyright',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Copyright?', 'proffer'),
            'default' => false,
            'on_text' => esc_html__('Yes', 'proffer'),
            'off_text' => esc_html__('No', 'proffer'),
            'label' => esc_html__('Yes, do it!', 'proffer'),
          ),
          array(
            'id'    => 'footer_copyright_layout',
            'type'  => 'image_select',
            'title' => esc_html__('Select Copyright Layout', 'proffer'),
            'info' => esc_html__('In above image, blue box is copyright text and yellow box is secondary text.', 'proffer'),
            'default'      => 'copyright-3',
            'options'      => array(
              'copyright-1'    => PROFFER_CS_IMAGES .'/footer/copyright-1.png',
              ),
            'radio'        => true,
            'dependency'     => array('hide_copyright', '!=', true),
          ),
          array(
            'id'    => 'copyright_text',
            'type'  => 'textarea',
            'title' => esc_html__('Copyright Text', 'proffer'),
            'shortcode' => true,
            'dependency' => array('hide_copyright', '!=', true),
            'after'       => 'Helpful shortcodes: [current_year] [home_url] or any shortcode.',
          ),

          // Copyright Another Text
          array(
            'type'    => 'notice',
            'class'   => 'warning cs-proffer-heading',
            'content' => esc_html__('Copyright Secondary Text', 'proffer'),
             'dependency'     => array('hide_copyright', '!=', true),
          ),
          array(
            'id'    => 'secondary_text',
            'type'  => 'textarea',
            'title' => esc_html__('Secondary Text', 'proffer'),
            'shortcode' => true,
            'dependency'     => array('hide_copyright', '!=', true),
          ),

        )
      ),

    ),
  );

  // ------------------------------
  // Design
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_design',
    'title'  => esc_html__('Design', 'proffer'),
    'icon'   => 'fa fa-magic'
  );

  // ------------------------------
  // color section
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_color_section',
    'title'    => esc_html__('Colors', 'proffer'),
    'icon'     => 'fa fa-eyedropper',
    'fields' => array(

      array(
        'type'    => 'heading',
        'content' => esc_html__('Color Options', 'proffer'),
      ),
      array(
        'type'    => 'subheading',
        'wrap_class' => 'color-tab-content',
        'content' => esc_html__('All color options are available in our theme customizer. The reason of we used customizer options for color section is because, you can choose each part of color from there and see the changes instantly using customizer. Highly customizable colors are in Appearance > Customize', 'proffer'),
      ),

    ),
  );

  // ------------------------------
  // Typography section
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_typo_section',
    'title'    => esc_html__('Typography', 'proffer'),
    'icon'     => 'fa fa-header',
    'fields' => array(

      // Start fields
      array(
        'id'                  => 'typography',
        'type'                => 'group',
        'fields'              => array(
          array(
            'id'              => 'title',
            'type'            => 'text',
            'title'           => esc_html__('Title', 'proffer'),
          ),
          array(
            'id'              => 'selector',
            'type'            => 'textarea',
            'title'           => esc_html__('Selector', 'proffer'),
            'info'           => wp_kses( __('Enter css selectors like : <strong>body, .custom-class</strong>', 'proffer'), array( 'strong' => array() ) ),
          ),
          array(
            'id'              => 'font',
            'type'            => 'typography',
            'title'           => esc_html__('Font Family', 'proffer'),
          ),
          array(
            'id'              => 'size',
            'type'            => 'text',
            'title'           => esc_html__('Font Size', 'proffer'),
          ),
          array(
            'id'              => 'line_height',
            'type'            => 'text',
            'title'           => esc_html__('Line-Height', 'proffer'),
          ),
          array(
            'id'              => 'css',
            'type'            => 'textarea',
            'title'           => esc_html__('Custom CSS', 'proffer'),
          ),
        ),
        'button_title'        => esc_html__('Add New Typography', 'proffer'),
        'accordion_title'     => esc_html__('New Typography', 'proffer'),
      ),

      // Subset
      array(
        'id'                  => 'subsets',
        'type'                => 'select',
        'title'               => esc_html__('Subsets', 'proffer'),
        'class'               => 'chosen',
        'options'             => array(
          'latin'             => 'latin',
          'latin-ext'         => 'latin-ext',
          'cyrillic'          => 'cyrillic',
          'cyrillic-ext'      => 'cyrillic-ext',
          'greek'             => 'greek',
          'greek-ext'         => 'greek-ext',
          'vietnamese'        => 'vietnamese',
          'devanagari'        => 'devanagari',
          'khmer'             => 'khmer',
        ),
        'attributes'         => array(
          'data-placeholder' => 'Subsets',
          'multiple'         => 'multiple',
          'style'            => 'width: 200px;'
        ),
        'default'             => array( 'latin' ),
      ),

      array(
        'id'                  => 'font_weight',
        'type'                => 'select',
        'title'               => esc_html__('Font Weights', 'proffer'),
        'class'               => 'chosen',
        'options'             => array(
          '100'   => esc_html__('Thin 100', 'proffer'),
          '100i'  => esc_html__('Thin 100 Italic', 'proffer'),
          '200'   => esc_html__('Extra Light 200', 'proffer'),
          '200i'  => esc_html__('Extra Light 200 Italic', 'proffer'),
          '300'   => esc_html__('Light 300', 'proffer'),
          '300i'  => esc_html__('Light 300 Italic', 'proffer'),
          '400'   => esc_html__('Regular 400', 'proffer'),
          '400i'  => esc_html__('Regular 400 Italic', 'proffer'),
          '500'   => esc_html__('Medium 500', 'proffer'),
          '500i'  => esc_html__('Medium 500 Italic', 'proffer'),
          '600'   => esc_html__('Semi Bold 600', 'proffer'),
          '600i'  => esc_html__('Semi Bold 600 Italic', 'proffer'),
          '700'   => esc_html__('Bold 700', 'proffer'),
          '700i'  => esc_html__('Bold 700 Italic', 'proffer'),
          '800'   => esc_html__('Extra Bold 800', 'proffer'),
          '800i'  => esc_html__('Extra Bold 800 Italic', 'proffer'),
          '900'   => esc_html__('Black 900', 'proffer'),
          '900i'  => esc_html__('Black 900 Italic', 'proffer'),
        ),
        'attributes'         => array(
          'data-placeholder' => esc_html__('Font Weight', 'proffer'),
          'multiple'         => 'multiple',
          'style'            => 'width: 200px;'
        ),
        'default'             => array( '400' ),
      ),

      // Custom Fonts Upload
      array(
        'id'                 => 'font_family',
        'type'               => 'group',
        'title'              => esc_html__('Upload Custom Fonts', 'proffer'),
        'button_title'       => esc_html__('Add New Custom Font', 'proffer'),
        'accordion_title'    => esc_html__('Adding New Font', 'proffer'),
        'accordion'          => true,
        'desc'               => esc_html__('It is simple. Only add your custom fonts and click to save. After you can check "Font Family" selector. Do not forget to Save!', 'proffer'),
        'fields'             => array(

          array(
            'id'             => 'name',
            'type'           => 'text',
            'title'          => esc_html__('Font-Family Name', 'proffer'),
            'attributes'     => array(
              'placeholder'  => esc_html__('for eg. Arial', 'proffer')
            ),
          ),

          array(
            'id'             => 'ttf',
            'type'           => 'upload',
            'title'          => wp_kses(__('Upload .ttf <small><i>(optional)</i></small>', 'proffer'), array( 'small' => array(), 'i' => array() )),
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => esc_html__('Use this Font-Format', 'proffer'),
              'button_title' => wp_kses(__('Upload <i>.ttf</i>', 'proffer'), array( 'i' => array() )),
            ),
          ),

          array(
            'id'             => 'eot',
            'type'           => 'upload',
            'title'          => wp_kses(__('Upload .eot <small><i>(optional)</i></small>', 'proffer'), array( 'small' => array(), 'i' => array() )),
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => esc_html__('Use this Font-Format', 'proffer'),
              'button_title' => wp_kses(__('Upload <i>.eot</i>', 'proffer'), array( 'i' => array() )),
            ),
          ),

          array(
            'id'             => 'otf',
            'type'           => 'upload',
            'title'          => wp_kses(__('Upload .otf <small><i>(optional)</i></small>', 'proffer'), array( 'small' => array(), 'i' => array() )),
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => esc_html__('Use this Font-Format', 'proffer'),
              'button_title' => wp_kses(__('Upload <i>.otf</i>', 'proffer'), array( 'i' => array() )),
            ),
          ),

          array(
            'id'             => 'woff',
            'type'           => 'upload',
            'title'          => wp_kses(__('Upload .woff <small><i>(optional)</i></small>', 'proffer'), array( 'small' => array(), 'i' => array() )),
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => esc_html__('Use this Font-Format', 'proffer'),
              'button_title' =>wp_kses(__('Upload <i>.woff</i>', 'proffer'), array( 'i' => array() )),
            ),
          ),

          array(
            'id'             => 'css',
            'type'           => 'textarea',
            'title'          => wp_kses(__('Extra CSS Style <small><i>(optional)</i></small>', 'proffer'), array( 'small' => array(), 'i' => array() )),
            'attributes'     => array(
              'placeholder'  => esc_html__('for eg. font-weight: normal;', 'proffer'),
            ),
          ),

        ),
      ),
      // End All field

    ),
  );

  // ------------------------------
  // Pages
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_pages',
    'title'  => esc_html__('Pages', 'proffer'),
    'icon'   => 'fa fa-files-o'
  );


  // ------------------------------
  // Team Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'team_section',
    'title'    => esc_html__('Team', 'proffer'),
    'icon'     => 'fa fa-address-book-o',
    'fields' => array(

      // team name change
      array(
        'type'    => 'notice',
        'class'   => 'info cs-tmx-heading',
        'content' => esc_html__('Name Change', 'proffer')
      ),
      array(
        'id'      => 'theme_team_name',
        'type'    => 'text',
        'title'   => esc_html__('Team Name', 'proffer'),
        'attributes'     => array(
          'placeholder'  => 'Team'
        ),
      ),
      array(
        'id'      => 'theme_team_slug',
        'type'    => 'text',
        'title'   => esc_html__('Team Slug', 'proffer'),
        'attributes'     => array(
          'placeholder'  => 'team-item'
        ),
      ),
      array(
        'id'      => 'theme_team_cat_slug',
        'type'    => 'text',
        'title'   => esc_html__('Team Category Slug', 'proffer'),
        'attributes'     => array(
          'placeholder'  => 'team-category'
        ),
      ),
      array(
        'type'    => 'notice',
        'class'   => 'danger',
        'content' => __('<strong>Important</strong>: Please do not set team slug and page slug as same. It\'ll not work.', 'proffer')
      ),
      // Team Start
      array(
        'type'    => 'notice',
        'class'   => 'info cs-proffer-heading',
        'content' => esc_html__('Team Single', 'proffer')
      ),
      array(
          'id'             => 'team_sidebar_position',
          'type'           => 'select',
          'title'          => esc_html__('Sidebar Position', 'proffer'),
          'options'        => array(
            'sidebar-right' => esc_html__('Right', 'proffer'),
            'sidebar-left' => esc_html__('Left', 'proffer'),
            'sidebar-hide' => esc_html__('Hide', 'proffer'),
          ),
          'default_option' => 'Select sidebar position',
          'info'          => esc_html__('Default option : Right', 'proffer'),
        ),
        array(
          'id'             => 'single_team_widget',
          'type'           => 'select',
          'title'          => esc_html__('Sidebar Widget', 'proffer'),
          'options'        => proffer_registered_sidebars(),
          'default_option' => esc_html__('Select Widget', 'proffer'),
          'dependency'     => array('team_sidebar_position', '!=', 'sidebar-hide'),
          'info'          => esc_html__('Default option : Main Widget Area', 'proffer'),
        ),
        array(
          'id'    => 'team_comment_form',
          'type'  => 'switcher',
          'title' => esc_html__('Comment Area/Form', 'proffer'),
          'info' => esc_html__('If need to hide comment area and that form on single blog page, please turn this OFF.', 'proffer'),
          'default' => true,
        ),
    ),
  );

  
  // ------------------------------
  // Event Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'event_section',
    'title'    => esc_html__('Event', 'proffer'),
    'icon'     => 'fa fa-medkit',
    'fields' => array(

      // event name change
      array(
        'type'    => 'notice',
        'class'   => 'info cs-tmx-heading',
        'content' => esc_html__('Name Change', 'proffer')
      ),
      array(
        'id'      => 'theme_event_name',
        'type'    => 'text',
        'title'   => esc_html__('Event Name', 'proffer'),
        'attributes'     => array(
          'placeholder'  => 'Event'
        ),
      ),
      array(
        'id'      => 'theme_event_slug',
        'type'    => 'text',
        'title'   => esc_html__('Event Slug', 'proffer'),
        'attributes'     => array(
          'placeholder'  => 'event-item'
        ),
      ),
      array(
        'id'      => 'theme_event_cat_slug',
        'type'    => 'text',
        'title'   => esc_html__('Event Category Slug', 'proffer'),
        'attributes'     => array(
          'placeholder'  => 'event-category'
        ),
      ),
      array(
        'type'    => 'notice',
        'class'   => 'danger',
        'content' => __('<strong>Important</strong>: Please do not set event slug and page slug as same. It\'ll not work.', 'proffer')
      ),

      // Event Start
      array(
        'type'    => 'notice',
        'class'   => 'info cs-proffer-heading',
        'content' => esc_html__('Event Single', 'proffer')
      ),
      array(
          'id'             => 'event_sidebar_position',
          'type'           => 'select',
          'title'          => esc_html__('Sidebar Position', 'proffer'),
          'options'        => array(
            'sidebar-right' => esc_html__('Right', 'proffer'),
            'sidebar-left' => esc_html__('Left', 'proffer'),
            'sidebar-hide' => esc_html__('Hide', 'proffer'),
          ),
          'default_option' => 'Select sidebar position',
          'info'          => esc_html__('Default option : Right', 'proffer'),
        ),
        array(
          'id'             => 'single_event_widget',
          'type'           => 'select',
          'title'          => esc_html__('Sidebar Widget', 'proffer'),
          'options'        => proffer_registered_sidebars(),
          'default_option' => esc_html__('Select Widget', 'proffer'),
          'dependency'     => array('event_sidebar_position', '!=', 'sidebar-hide'),
          'info'          => esc_html__('Default option : Main Widget Area', 'proffer'),
        ),
        array(
          'id'    => 'event_comment_form',
          'type'  => 'switcher',
          'title' => esc_html__('Comment Area/Form', 'proffer'),
          'info' => esc_html__('If need to hide comment area and that form on single blog page, please turn this OFF.', 'proffer'),
          'default' => true,
        ),
    ),
  );

  // ------------------------------
  // Blog Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'blog_section',
    'title'    => esc_html__('Blog', 'proffer'),
    'icon'     => 'fa fa-edit',
    'sections' => array(

      // blog general section
      array(
        'name'     => 'blog_general_tab',
        'title'    => esc_html__('General', 'proffer'),
        'icon'     => 'fa fa-cog',
        'fields'   => array(

          // Layout
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Layout', 'proffer')
          ),
          array(
            'id'             => 'blog_sidebar_position',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Position', 'proffer'),
            'options'        => array(
              'sidebar-right' => esc_html__('Right', 'proffer'),
              'sidebar-left' => esc_html__('Left', 'proffer'),
              'sidebar-hide' => esc_html__('Hide', 'proffer'),
            ),
            'default_option' => 'Select sidebar position',
            'help'          => esc_html__('This style will apply, default blog pages - Like : Archive, Category, Tags, Search & Author.', 'proffer'),
            'info'          => esc_html__('Default option : Right', 'proffer'),
          ),
          array(
            'id'             => 'blog_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'proffer'),
            'options'        => proffer_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'proffer'),
            'dependency'     => array('blog_sidebar_position', '!=', 'sidebar-hide'),
            'info'          => esc_html__('Default option : Main Widget Area', 'proffer'),
          ),
          // Layout
          // Global Options
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Global Options', 'proffer')
          ),
          array(
            'id'         => 'theme_exclude_categories',
            'type'       => 'checkbox',
            'title'      => esc_html__('Exclude Categories', 'proffer'),
            'info'      => esc_html__('Select categories you want to exclude from blog page.', 'proffer'),
            'options'    => 'categories',
          ),
          array(
            'id'      => 'theme_blog_excerpt',
            'type'    => 'text',
            'title'   => esc_html__('Excerpt Length', 'proffer'),
            'info'   => esc_html__('Blog short content length, in blog listing pages.', 'proffer'),
            'default' => '55',
          ),
          array(
            'id'      => 'theme_metas_hide',
            'type'    => 'checkbox',
            'title'   => esc_html__('Meta\'s to hide', 'proffer'),
            'info'    => esc_html__('Check items you want to hide from blog/post meta field.', 'proffer'),
            'class'      => 'horizontal',
            'options'    => array(
              'category'   => esc_html__('Category', 'proffer'),
              'date'    => esc_html__('Date', 'proffer'),
              'author'     => esc_html__('Author', 'proffer'),
              'comments'      => esc_html__('Comments', 'proffer'),
              'Tag'      => esc_html__('Tag', 'proffer'),
            ),
            // 'default' => '30',
          ),
          // End fields

        )
      ),

      // blog single section
      array(
        'name'     => 'blog_single_tab',
        'title'    => esc_html__('Single', 'proffer'),
        'icon'     => 'fa fa-sticky-note',
        'fields'   => array(

          // Start fields
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Enable / Disable', 'proffer')
          ),
          array(
            'id'    => 'single_featured_image',
            'type'  => 'switcher',
            'title' => esc_html__('Featured Image', 'proffer'),
            'info' => esc_html__('If need to hide featured image from single blog post page, please turn this OFF.', 'proffer'),
            'default' => true,
          ),
           array(
            'id'    => 'single_author_info',
            'type'  => 'switcher',
            'title' => esc_html__('Author Info', 'proffer'),
            'info' => esc_html__('If need to hide author info on single blog page, please turn this On.', 'proffer'),
            'default' => false,
          ),
          array(
            'id'    => 'single_share_option',
            'type'  => 'switcher',
            'title' => esc_html__('Share Option', 'proffer'),
            'info' => esc_html__('If need to hide share option on single blog page, please turn this OFF.', 'proffer'),
            'default' => true,
          ),
          array(
            'id'    => 'single_comment_form',
            'type'  => 'switcher',
            'title' => esc_html__('Comment Area/Form ?', 'proffer'),
            'info' => esc_html__('If need to hide comment area and that form on single blog page, please turn this On.', 'proffer'),
            'default' => false,
          ),
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Sidebar', 'proffer')
          ),
          array(
            'id'             => 'single_sidebar_position',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Position', 'proffer'),
            'options'        => array(
              'sidebar-right' => esc_html__('Right', 'proffer'),
              'sidebar-left' => esc_html__('Left', 'proffer'),
              'sidebar-hide' => esc_html__('Hide', 'proffer'),
            ),
            'default_option' => 'Select sidebar position',
            'info'          => esc_html__('Default option : Right', 'proffer'),
          ),
          array(
            'id'             => 'single_blog_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'proffer'),
            'options'        => proffer_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'proffer'),
            'dependency'     => array('single_sidebar_position', '!=', 'sidebar-hide'),
            'info'          => esc_html__('Default option : Main Widget Area', 'proffer'),
          ),
          // End fields

        )
      ),

    ),
  );

if (class_exists( 'WooCommerce' )){
  // ------------------------------
  // WooCommerce Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'woocommerce_section',
    'title'    => esc_html__('WooCommerce', 'proffer'),
    'icon'     => 'fa fa-shopping-cart',
    'fields' => array(

      // Start fields
      array(
        'type'    => 'notice',
        'class'   => 'info cs-proffer-heading',
        'content' => esc_html__('Layout', 'proffer')
      ),
     array(
        'id'             => 'woo_product_columns',
        'type'           => 'select',
        'title'          => esc_html__('Product Column', 'proffer'),
        'options'        => array(
          2 => esc_html__('Two Column', 'proffer'),
          3 => esc_html__('Three Column', 'proffer'),
          4 => esc_html__('Four Column', 'proffer'),
        ),
        'default_option' => esc_html__('Select Product Columns', 'proffer'),
        'help'          => esc_html__('This style will apply, default woocommerce shop and archive pages.', 'proffer'),
      ),
      array(
        'id'             => 'woo_sidebar_position',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Position', 'proffer'),
        'options'        => array(
          'right-sidebar' => esc_html__('Right', 'proffer'),
          'left-sidebar' => esc_html__('Left', 'proffer'),
          'sidebar-hide' => esc_html__('Hide', 'proffer'),
        ),
        'default_option' => esc_html__('Select sidebar position', 'proffer'),
        'info'          => esc_html__('Default option : Right', 'proffer'),
      ),
      array(
        'id'             => 'woo_widget',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Widget', 'proffer'),
        'options'        => proffer_registered_sidebars(),
        'default_option' => esc_html__('Select Widget', 'proffer'),
        'dependency'     => array('woo_sidebar_position', '!=', 'sidebar-hide'),
        'info'          => esc_html__('Default option : Shop Page', 'proffer'),
      ),

      array(
        'type'    => 'notice',
        'class'   => 'info cs-proffer-heading',
        'content' => esc_html__('Listing', 'proffer')
      ),
      array(
        'id'      => 'theme_woo_limit',
        'type'    => 'text',
        'title'   => esc_html__('Product Limit', 'proffer'),
        'info'   => esc_html__('Enter the number value for per page products limit.', 'proffer'),
      ),
      // End fields

      // Start fields
      array(
        'type'    => 'notice',
        'class'   => 'info cs-proffer-heading',
        'content' => esc_html__('Single Product', 'proffer')
      ),
      array(
        'id'             => 'woo_related_limit',
        'type'           => 'text',
        'title'          => esc_html__('Related Products Limit', 'proffer'),
      ),
      array(
        'id'    => 'woo_single_upsell',
        'type'  => 'switcher',
        'title' => esc_html__('You May Also Like', 'proffer'),
        'info' => esc_html__('If you don\'t want \'You May Also Like\' products in single product page, please turn this ON.', 'proffer'),
        'default' => false,
      ),
      array(
        'id'    => 'woo_single_related',
        'type'  => 'switcher',
        'title' => esc_html__('Related Products', 'proffer'),
        'info' => esc_html__('If you don\'t want \'Related Products\' in single product page, please turn this ON.', 'proffer'),
        'default' => false,
      ),
      // End fields

    ),
  );
}

  // ------------------------------
  // Extra Pages
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_extra_pages',
    'title'    => esc_html__('Extra Pages', 'proffer'),
    'icon'     => 'fa fa-clone',
    'sections' => array(

      // error 404 page
      array(
        'name'     => 'error_page_section',
        'title'    => esc_html__('404 Page', 'proffer'),
        'icon'     => 'fa fa-exclamation-triangle',
        'fields'   => array(

          // Start 404 Page
          array(
            'id'    => 'error_heading',
            'type'  => 'text',
            'title' => esc_html__('404 Page Heading', 'proffer'),
            'info'  => esc_html__('Enter 404 page heading.', 'proffer'),
          ),
          array(
            'id'    => 'error_subheading',
            'type'  => 'textarea',
            'title' => esc_html__('404 Page Sub Heading', 'proffer'),
            'info'  => esc_html__('Enter 404 page Sub heading.', 'proffer'),
          ),
          array(
            'id'    => 'error_page_content',
            'type'  => 'textarea',
            'title' => esc_html__('404 Page Content', 'proffer'),
            'info'  => esc_html__('Enter 404 page content.', 'proffer'),
            'shortcode' => true,
          ),
          array(
            'id'    => 'error_btn_text',
            'type'  => 'text',
            'title' => esc_html__('Button Text', 'proffer'),
            'info'  => esc_html__('Enter BACK TO HOME button text. If you want to change it.', 'proffer'),
          ),
          // End 404 Page

        ) // end: fields
      ), // end: fields section

      // maintenance mode page
      array(
        'name'     => 'maintenance_mode_section',
        'title'    => esc_html__('Maintenance Mode', 'proffer'),
        'icon'     => 'fa fa-hourglass-half',
        'fields'   => array(

          // Start Maintenance Mode
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('If you turn this ON : Only Logged in users will see your pages. All other visiters will see, selected page of : <strong>Maintenance Mode Page</strong>', 'proffer')
          ),
          array(
            'id'             => 'enable_maintenance_mode',
            'type'           => 'switcher',
            'title'          => esc_html__('Maintenance Mode', 'proffer'),
            'default'        => false,
          ),
          array(
            'id'             => 'maintenance_mode_page',
            'type'           => 'select',
            'title'          => esc_html__('Maintenance Mode Page', 'proffer'),
            'options'        => 'pages',
            'default_option' => esc_html__('Select a page', 'proffer'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          array(
            'id'             => 'maintenance_mode_title',
            'type'           => 'text',
            'title'          => esc_html__('Maintenance Mode Text', 'proffer'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          array(
            'id'             => 'maintenance_mode_text',
            'type'           => 'textarea',
            'title'          => esc_html__('Maintenance Mode Text', 'proffer'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          array(
            'id'             => 'maintenance_mode_bg',
            'type'           => 'background',
            'title'          => esc_html__('Page Background', 'proffer'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          // End Maintenance Mode

        ) // end: fields
      ), // end: fields section

    )
  );

  // ------------------------------
  // Advanced
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_advanced',
    'title'  => esc_html__('Advanced', 'proffer'),
    'icon'   => 'fa fa-cog'
  );

  // ------------------------------
  // Misc Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'misc_section',
    'title'    => esc_html__('Misc', 'proffer'),
    'icon'     => 'fa fa-recycle',
    'sections' => array(

      // custom sidebar section
      array(
        'name'     => 'custom_sidebar_section',
        'title'    => esc_html__('Custom Sidebar', 'proffer'),
        'icon'     => 'fa fa-reorder',
        'fields'   => array(

          // start fields
          array(
            'id'              => 'custom_sidebar',
            'title'           => esc_html__('Sidebars', 'proffer'),
            'desc'            => esc_html__('Go to Appearance -> Widgets after create sidebars', 'proffer'),
            'type'            => 'group',
            'fields'          => array(
              array(
                'id'          => 'sidebar_name',
                'type'        => 'text',
                'title'       => esc_html__('Sidebar Name', 'proffer'),
              ),
              array(
                'id'          => 'sidebar_desc',
                'type'        => 'text',
                'title'       => esc_html__('Custom Description', 'proffer'),
              )
            ),
            'accordion'       => true,
            'button_title'    => esc_html__('Add New Sidebar', 'proffer'),
            'accordion_title' => esc_html__('New Sidebar', 'proffer'),
          ),
          // end fields

        )
      ),
      // custom sidebar section

      // Custom CSS/JS
      array(
        'name'        => 'custom_css_js_section',
        'title'       => esc_html__('Custom Codes', 'proffer'),
        'icon'        => 'fa fa-code',

        // begin: fields
        'fields'      => array(
          // Start Custom CSS/JS
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Custom JS', 'proffer')
          ),
          array(
            'id'             => 'theme_custom_js',
            'type'           => 'textarea',
            'attributes' => array(
              'rows'     => 10,
              'placeholder'     => esc_html__('Enter your JS code here...', 'proffer'),
            ),
          ),
          // End Custom CSS/JS

        ) // end: fields
      ),

      // Translation
      array(
        'name'        => 'theme_translation_section',
        'title'       => esc_html__('Translation', 'proffer'),
        'icon'        => 'fa fa-language',

        // begin: fields
        'fields'      => array(

          // Start Translation
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Common Texts', 'proffer')
          ),
          array(
            'id'          => 'read_more_text',
            'type'        => 'text',
            'title'       => esc_html__('Read More Text', 'proffer'),
          ),
          array(
            'id'          => 'view_more_text',
            'type'        => 'text',
            'title'       => esc_html__('View More Text', 'proffer'),
          ),
          array(
            'id'          => 'share_text',
            'type'        => 'text',
            'title'       => esc_html__('Share Text', 'proffer'),
          ),
          array(
            'id'          => 'share_on_text',
            'type'        => 'text',
            'title'       => esc_html__('Share On Tooltip Text', 'proffer'),
          ),
          array(
            'id'          => 'author_text',
            'type'        => 'text',
            'title'       => esc_html__('Author Text', 'proffer'),
          ),
          array(
            'id'          => 'post_comment_text',
            'type'        => 'text',
            'title'       => esc_html__('Post Comment Text [Submit Button]', 'proffer'),
          ),
          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('WooCommerce', 'proffer')
          ),
          array(
            'id'          => 'add_to_cart_text',
            'type'        => 'text',
            'title'       => esc_html__('Add to Cart Text', 'proffer'),
          ),
          array(
            'id'          => 'details_text',
            'type'        => 'text',
            'title'       => esc_html__('Details Text', 'proffer'),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Pagination', 'proffer')
          ),
          array(
            'id'          => 'older_post',
            'type'        => 'text',
            'title'       => esc_html__('Older Posts Text', 'proffer'),
          ),
          array(
            'id'          => 'newer_post',
            'type'        => 'text',
            'title'       => esc_html__('Newer Posts Text', 'proffer'),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-proffer-heading',
            'content' => esc_html__('Single Portfolio Pagination', 'proffer')
          ),
          array(
            'id'          => 'prev_port',
            'type'        => 'text',
            'title'       => esc_html__('Prev Case Text', 'proffer'),
          ),
          array(
            'id'          => 'next_port',
            'type'        => 'text',
            'title'       => esc_html__('Next Case Text', 'proffer'),
          ),
          // End Translation

        ) // end: fields
      ),

    ),
  );

  
  // ------------------------------
  // backup                       -
  // ------------------------------
  $options[]   = array(
    'name'     => 'backup_section',
    'title'    => 'Backup',
    'icon'     => 'fa fa-shield',
    'fields'   => array(

      array(
        'type'    => 'notice',
        'class'   => 'warning',
        'content' => esc_html__('You can save your current options. Download a Backup and Import.', 'proffer'),
      ),

      array(
        'type'    => 'backup',
      ),

    )
  );

  return $options;

}
add_filter( 'cs_framework_options', 'proffer_options' );